#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Word list originally created by dabura667 and released under The MIT License (MIT)
#
# The MIT License (MIT)
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
# Code surrounding the word list is Copyright (c) 2014-2018, The Monero Project
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this list of
#    conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice, this list
#    of conditions and the following disclaimer in the documentation and/or other
#    materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its contributors may be
#    used to endorse or promote products derived from this software without specific
#    prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
# THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
# THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# list of words from:
#     https://github.com/monero-project/monero/blob/master/src/mnemonics/portuguese.h
#     Most recent commit: 8ea3c4d54429976e9001b8cc4868b721e6747e3c


from .wordlist import Wordlist


class Portuguese(Wordlist):
    language_name = u"Português"
    english_language_name = "Portuguese"
    unique_prefix_length = 4
    word_list = [
        "abaular",
        "abdominal",
        "abeto",
        "abissinio",
        "abjeto",
        "ablucao",
        "abnegar",
        "abotoar",
        "abrutalhar",
        "absurdo",
        "abutre",
        "acautelar",
        "accessorios",
        "acetona",
        "achocolatado",
        "acirrar",
        "acne",
        "acovardar",
        "acrostico",
        "actinomicete",
        "acustico",
        "adaptavel",
        "adeus",
        "adivinho",
        "adjunto",
        "admoestar",
        "adnominal",
        "adotivo",
        "adquirir",
        "adriatico",
        "adsorcao",
        "adutora",
        "advogar",
        "aerossol",
        "afazeres",
        "afetuoso",
        "afixo",
        "afluir",
        "afortunar",
        "afrouxar",
        "aftosa",
        "afunilar",
        "agentes",
        "agito",
        "aglutinar",
        "aiatola",
        "aimore",
        "aino",
        "aipo",
        "airoso",
        "ajeitar",
        "ajoelhar",
        "ajudante",
        "ajuste",
        "alazao",
        "albumina",
        "alcunha",
        "alegria",
        "alexandre",
        "alforriar",
        "alguns",
        "alhures",
        "alivio",
        "almoxarife",
        "alotropico",
        "alpiste",
        "alquimista",
        "alsaciano",
        "altura",
        "aluviao",
        "alvura",
        "amazonico",
        "ambulatorio",
        "ametodico",
        "amizades",
        "amniotico",
        "amovivel",
        "amurada",
        "anatomico",
        "ancorar",
        "anexo",
        "anfora",
        "aniversario",
        "anjo",
        "anotar",
        "ansioso",
        "anturio",
        "anuviar",
        "anverso",
        "anzol",
        "aonde",
        "apaziguar",
        "apito",
        "aplicavel",
        "apoteotico",
        "aprimorar",
        "aprumo",
        "apto",
        "apuros",
        "aquoso",
        "arauto",
        "arbusto",
        "arduo",
        "aresta",
        "arfar",
        "arguto",
        "aritmetico",
        "arlequim",
        "armisticio",
        "aromatizar",
        "arpoar",
        "arquivo",
        "arrumar",
        "arsenio",
        "arturiano",
        "aruaque",
        "arvores",
        "asbesto",
        "ascorbico",
        "aspirina",
        "asqueroso",
        "assustar",
        "astuto",
        "atazanar",
        "ativo",
        "atletismo",
        "atmosferico",
        "atormentar",
        "atroz",
        "aturdir",
        "audivel",
        "auferir",
        "augusto",
        "aula",
        "aumento",
        "aurora",
        "autuar",
        "avatar",
        "avexar",
        "avizinhar",
        "avolumar",
        "avulso",
        "axiomatico",
        "azerbaijano",
        "azimute",
        "azoto",
        "azulejo",
        "bacteriologista",
        "badulaque",
        "baforada",
        "baixote",
        "bajular",
        "balzaquiana",
        "bambuzal",
        "banzo",
        "baoba",
        "baqueta",
        "barulho",
        "bastonete",
        "batuta",
        "bauxita",
        "bavaro",
        "bazuca",
        "bcrepuscular",
        "beato",
        "beduino",
        "begonia",
        "behaviorista",
        "beisebol",
        "belzebu",
        "bemol",
        "benzido",
        "beocio",
        "bequer",
        "berro",
        "besuntar",
        "betume",
        "bexiga",
        "bezerro",
        "biatlon",
        "biboca",
        "bicuspide",
        "bidirecional",
        "bienio",
        "bifurcar",
        "bigorna",
        "bijuteria",
        "bimotor",
        "binormal",
        "bioxido",
        "bipolarizacao",
        "biquini",
        "birutice",
        "bisturi",
        "bituca",
        "biunivoco",
        "bivalve",
        "bizarro",
        "blasfemo",
        "blenorreia",
        "blindar",
        "bloqueio",
        "blusao",
        "boazuda",
        "bofete",
        "bojudo",
        "bolso",
        "bombordo",
        "bonzo",
        "botina",
        "boquiaberto",
        "bostoniano",
        "botulismo",
        "bourbon",
        "bovino",
        "boximane",
        "bravura",
        "brevidade",
        "britar",
        "broxar",
        "bruno",
        "bruxuleio",
        "bubonico",
        "bucolico",
        "buda",
        "budista",
        "bueiro",
        "buffer",
        "bugre",
        "bujao",
        "bumerangue",
        "burundines",
        "busto",
        "butique",
        "buzios",
        "caatinga",
        "cabuqui",
        "cacunda",
        "cafuzo",
        "cajueiro",
        "camurca",
        "canudo",
        "caquizeiro",
        "carvoeiro",
        "casulo",
        "catuaba",
        "cauterizar",
        "cebolinha",
        "cedula",
        "ceifeiro",
        "celulose",
        "cerzir",
        "cesto",
        "cetro",
        "ceus",
        "cevar",
        "chavena",
        "cheroqui",
        "chita",
        "chovido",
        "chuvoso",
        "ciatico",
        "cibernetico",
        "cicuta",
        "cidreira",
        "cientistas",
        "cifrar",
        "cigarro",
        "cilio",
        "cimo",
        "cinzento",
        "cioso",
        "cipriota",
        "cirurgico",
        "cisto",
        "citrico",
        "ciumento",
        "civismo",
        "clavicula",
        "clero",
        "clitoris",
        "cluster",
        "coaxial",
        "cobrir",
        "cocota",
        "codorniz",
        "coexistir",
        "cogumelo",
        "coito",
        "colusao",
        "compaixao",
        "comutativo",
        "contentamento",
        "convulsivo",
        "coordenativa",
        "coquetel",
        "correto",
        "corvo",
        "costureiro",
        "cotovia",
        "covil",
        "cozinheiro",
        "cretino",
        "cristo",
        "crivo",
        "crotalo",
        "cruzes",
        "cubo",
        "cucuia",
        "cueiro",
        "cuidar",
        "cujo",
        "cultural",
        "cunilingua",
        "cupula",
        "curvo",
        "custoso",
        "cutucar",
        "czarismo",
        "dablio",
        "dacota",
        "dados",
        "daguerreotipo",
        "daiquiri",
        "daltonismo",
        "damista",
        "dantesco",
        "daquilo",
        "darwinista",
        "dasein",
        "dativo",
        "deao",
        "debutantes",
        "decurso",
        "deduzir",
        "defunto",
        "degustar",
        "dejeto",
        "deltoide",
        "demover",
        "denunciar",
        "deputado",
        "deque",
        "dervixe",
        "desvirtuar",
        "deturpar",
        "deuteronomio",
        "devoto",
        "dextrose",
        "dezoito",
        "diatribe",
        "dicotomico",
        "didatico",
        "dietista",
        "difuso",
        "digressao",
        "diluvio",
        "diminuto",
        "dinheiro",
        "dinossauro",
        "dioxido",
        "diplomatico",
        "dique",
        "dirimivel",
        "disturbio",
        "diurno",
        "divulgar",
        "dizivel",
        "doar",
        "dobro",
        "docura",
        "dodoi",
        "doer",
        "dogue",
        "doloso",
        "domo",
        "donzela",
        "doping",
        "dorsal",
        "dossie",
        "dote",
        "doutro",
        "doze",
        "dravidico",
        "dreno",
        "driver",
        "dropes",
        "druso",
        "dubnio",
        "ducto",
        "dueto",
        "dulija",
        "dundum",
        "duodeno",
        "duquesa",
        "durou",
        "duvidoso",
        "duzia",
        "ebano",
        "ebrio",
        "eburneo",
        "echarpe",
        "eclusa",
        "ecossistema",
        "ectoplasma",
        "ecumenismo",
        "eczema",
        "eden",
        "editorial",
        "edredom",
        "edulcorar",
        "efetuar",
        "efigie",
        "efluvio",
        "egiptologo",
        "egresso",
        "egua",
        "einsteiniano",
        "eira",
        "eivar",
        "eixos",
        "ejetar",
        "elastomero",
        "eldorado",
        "elixir",
        "elmo",
        "eloquente",
        "elucidativo",
        "emaranhar",
        "embutir",
        "emerito",
        "emfa",
        "emitir",
        "emotivo",
        "empuxo",
        "emulsao",
        "enamorar",
        "encurvar",
        "enduro",
        "enevoar",
        "enfurnar",
        "enguico",
        "enho",
        "enigmista",
        "enlutar",
        "enormidade",
        "enpreendimento",
        "enquanto",
        "enriquecer",
        "enrugar",
        "entusiastico",
        "enunciar",
        "envolvimento",
        "enxuto",
        "enzimatico",
        "eolico",
        "epiteto",
        "epoxi",
        "epura",
        "equivoco",
        "erario",
        "erbio",
        "ereto",
        "erguido",
        "erisipela",
        "ermo",
        "erotizar",
        "erros",
        "erupcao",
        "ervilha",
        "esburacar",
        "escutar",
        "esfuziante",
        "esguio",
        "esloveno",
        "esmurrar",
        "esoterismo",
        "esperanca",
        "espirito",
        "espurio",
        "essencialmente",
        "esturricar",
        "esvoacar",
        "etario",
        "eterno",
        "etiquetar",
        "etnologo",
        "etos",
        "etrusco",
        "euclidiano",
        "euforico",
        "eugenico",
        "eunuco",
        "europio",
        "eustaquio",
        "eutanasia",
        "evasivo",
        "eventualidade",
        "evitavel",
        "evoluir",
        "exaustor",
        "excursionista",
        "exercito",
        "exfoliado",
        "exito",
        "exotico",
        "expurgo",
        "exsudar",
        "extrusora",
        "exumar",
        "fabuloso",
        "facultativo",
        "fado",
        "fagulha",
        "faixas",
        "fajuto",
        "faltoso",
        "famoso",
        "fanzine",
        "fapesp",
        "faquir",
        "fartura",
        "fastio",
        "faturista",
        "fausto",
        "favorito",
        "faxineira",
        "fazer",
        "fealdade",
        "febril",
        "fecundo",
        "fedorento",
        "feerico",
        "feixe",
        "felicidade",
        "felpudo",
        "feltro",
        "femur",
        "fenotipo",
        "fervura",
        "festivo",
        "feto",
        "feudo",
        "fevereiro",
        "fezinha",
        "fiasco",
        "fibra",
        "ficticio",
        "fiduciario",
        "fiesp",
        "fifa",
        "figurino",
        "fijiano",
        "filtro",
        "finura",
        "fiorde",
        "fiquei",
        "firula",
        "fissurar",
        "fitoteca",
        "fivela",
        "fixo",
        "flavio",
        "flexor",
        "flibusteiro",
        "flotilha",
        "fluxograma",
        "fobos",
        "foco",
        "fofura",
        "foguista",
        "foie",
        "foliculo",
        "fominha",
        "fonte",
        "forum",
        "fosso",
        "fotossintese",
        "foxtrote",
        "fraudulento",
        "frevo",
        "frivolo",
        "frouxo",
        "frutose",
        "fuba",
        "fucsia",
        "fugitivo",
        "fuinha",
        "fujao",
        "fulustreco",
        "fumo",
        "funileiro",
        "furunculo",
        "fustigar",
        "futurologo",
        "fuxico",
        "fuzue",
        "gabriel",
        "gado",
        "gaelico",
        "gafieira",
        "gaguejo",
        "gaivota",
        "gajo",
        "galvanoplastico",
        "gamo",
        "ganso",
        "garrucha",
        "gastronomo",
        "gatuno",
        "gaussiano",
        "gaviao",
        "gaxeta",
        "gazeteiro",
        "gear",
        "geiser",
        "geminiano",
        "generoso",
        "genuino",
        "geossinclinal",
        "gerundio",
        "gestual",
        "getulista",
        "gibi",
        "gigolo",
        "gilete",
        "ginseng",
        "giroscopio",
        "glaucio",
        "glacial",
        "gleba",
        "glifo",
        "glote",
        "glutonia",
        "gnostico",
        "goela",
        "gogo",
        "goitaca",
        "golpista",
        "gomo",
        "gonzo",
        "gorro",
        "gostou",
        "goticula",
        "gourmet",
        "governo",
        "gozo",
        "graxo",
        "grevista",
        "grito",
        "grotesco",
        "gruta",
        "guaxinim",
        "gude",
        "gueto",
        "guizo",
        "guloso",
        "gume",
        "guru",
        "gustativo",
        "grelhado",
        "gutural",
        "habitue",
        "haitiano",
        "halterofilista",
        "hamburguer",
        "hanseniase",
        "happening",
        "harpista",
        "hastear",
        "haveres",
        "hebreu",
        "hectometro",
        "hedonista",
        "hegira",
        "helena",
        "helminto",
        "hemorroidas",
        "henrique",
        "heptassilabo",
        "hertziano",
        "hesitar",
        "heterossexual",
        "heuristico",
        "hexagono",
        "hiato",
        "hibrido",
        "hidrostatico",
        "hieroglifo",
        "hifenizar",
        "higienizar",
        "hilario",
        "himen",
        "hino",
        "hippie",
        "hirsuto",
        "historiografia",
        "hitlerista",
        "hodometro",
        "hoje",
        "holograma",
        "homus",
        "honroso",
        "hoquei",
        "horto",
        "hostilizar",
        "hotentote",
        "huguenote",
        "humilde",
        "huno",
        "hurra",
        "hutu",
        "iaia",
        "ialorixa",
        "iambico",
        "iansa",
        "iaque",
        "iara",
        "iatista",
        "iberico",
        "ibis",
        "icar",
        "iceberg",
        "icosagono",
        "idade",
        "ideologo",
        "idiotice",
        "idoso",
        "iemenita",
        "iene",
        "igarape",
        "iglu",
        "ignorar",
        "igreja",
        "iguaria",
        "iidiche",
        "ilativo",
        "iletrado",
        "ilharga",
        "ilimitado",
        "ilogismo",
        "ilustrissimo",
        "imaturo",
        "imbuzeiro",
        "imerso",
        "imitavel",
        "imovel",
        "imputar",
        "imutavel",
        "inaveriguavel",
        "incutir",
        "induzir",
        "inextricavel",
        "infusao",
        "ingua",
        "inhame",
        "iniquo",
        "injusto",
        "inning",
        "inoxidavel",
        "inquisitorial",
        "insustentavel",
        "intumescimento",
        "inutilizavel",
        "invulneravel",
        "inzoneiro",
        "iodo",
        "iogurte",
        "ioio",
        "ionosfera",
        "ioruba",
        "iota",
        "ipsilon",
        "irascivel",
        "iris",
        "irlandes",
        "irmaos",
        "iroques",
        "irrupcao",
        "isca",
        "isento",
        "islandes",
        "isotopo",
        "isqueiro",
        "israelita",
        "isso",
        "isto",
        "iterbio",
        "itinerario",
        "itrio",
        "iuane",
        "iugoslavo",
        "jabuticabeira",
        "jacutinga",
        "jade",
        "jagunco",
        "jainista",
        "jaleco",
        "jambo",
        "jantarada",
        "japones",
        "jaqueta",
        "jarro",
        "jasmim",
        "jato",
        "jaula",
        "javel",
        "jazz",
        "jegue",
        "jeitoso",
        "jejum",
        "jenipapo",
        "jeova",
        "jequitiba",
        "jersei",
        "jesus",
        "jetom",
        "jiboia",
        "jihad",
        "jilo",
        "jingle",
        "jipe",
        "jocoso",
        "joelho",
        "joguete",
        "joio",
        "jojoba",
        "jorro",
        "jota",
        "joule",
        "joviano",
        "jubiloso",
        "judoca",
        "jugular",
        "juizo",
        "jujuba",
        "juliano",
        "jumento",
        "junto",
        "jururu",
        "justo",
        "juta",
        "juventude",
        "labutar",
        "laguna",
        "laico",
        "lajota",
        "lanterninha",
        "lapso",
        "laquear",
        "lastro",
        "lauto",
        "lavrar",
        "laxativo",
        "lazer",
        "leasing",
        "lebre",
        "lecionar",
        "ledo",
        "leguminoso",
        "leitura",
        "lele",
        "lemure",
        "lento",
        "leonardo",
        "leopardo",
        "lepton",
        "leque",
        "leste",
        "letreiro",
        "leucocito",
        "levitico",
        "lexicologo",
        "lhama",
        "lhufas",
        "liame",
        "licoroso",
        "lidocaina",
        "liliputiano",
        "limusine",
        "linotipo",
        "lipoproteina",
        "liquidos",
        "lirismo",
        "lisura",
        "liturgico",
        "livros",
        "lixo",
        "lobulo",
        "locutor",
        "lodo",
        "logro",
        "lojista",
        "lombriga",
        "lontra",
        "loop",
        "loquaz",
        "lorota",
        "losango",
        "lotus",
        "louvor",
        "luar",
        "lubrificavel",
        "lucros",
        "lugubre",
        "luis",
        "luminoso",
        "luneta",
        "lustroso",
        "luto",
        "luvas",
        "luxuriante",
        "luzeiro",
        "maduro",
        "maestro",
        "mafioso",
        "magro",
        "maiuscula",
        "majoritario",
        "malvisto",
        "mamute",
        "manutencao",
        "mapoteca",
        "maquinista",
        "marzipa",
        "masturbar",
        "matuto",
        "mausoleu",
        "mavioso",
        "maxixe",
        "mazurca",
        "meandro",
        "mecha",
        "medusa",
        "mefistofelico",
        "megera",
        "meirinho",
        "melro",
        "memorizar",
        "menu",
        "mequetrefe",
        "mertiolate",
        "mestria",
        "metroviario",
        "mexilhao",
        "mezanino",
        "miau",
        "microssegundo",
        "midia",
        "migratorio",
        "mimosa",
        "minuto",
        "miosotis",
        "mirtilo",
        "misturar",
        "mitzvah",
        "miudos",
        "mixuruca",
        "mnemonico",
        "moagem",
        "mobilizar",
        "modulo",
        "moer",
        "mofo",
        "mogno",
        "moita",
        "molusco",
        "monumento",
        "moqueca",
        "morubixaba",
        "mostruario",
        "motriz",
        "mouse",
        "movivel",
        "mozarela",
        "muarra",
        "muculmano",
        "mudo",
        "mugir",
        "muitos",
        "mumunha",
        "munir",
        "muon",
        "muquira",
        "murros",
        "musselina",
        "nacoes",
        "nado",
        "naftalina",
        "nago",
        "naipe",
        "naja",
        "nalgum",
        "namoro",
        "nanquim",
        "napolitano",
        "naquilo",
        "nascimento",
        "nautilo",
        "navios",
        "nazista",
        "nebuloso",
        "nectarina",
        "nefrologo",
        "negus",
        "nelore",
        "nenufar",
        "nepotismo",
        "nervura",
        "neste",
        "netuno",
        "neutron",
        "nevoeiro",
        "newtoniano",
        "nexo",
        "nhenhenhem",
        "nhoque",
        "nigeriano",
        "niilista",
        "ninho",
        "niobio",
        "niponico",
        "niquelar",
        "nirvana",
        "nisto",
        "nitroglicerina",
        "nivoso",
        "nobreza",
        "nocivo",
        "noel",
        "nogueira",
        "noivo",
        "nojo",
        "nominativo",
        "nonuplo",
        "noruegues",
        "nostalgico",
        "noturno",
        "nouveau",
        "nuanca",
        "nublar",
        "nucleotideo",
        "nudista",
        "nulo",
        "numismatico",
        "nunquinha",
        "nupcias",
        "nutritivo",
        "nuvens",
        "oasis",
        "obcecar",
        "obeso",
        "obituario",
        "objetos",
        "oblongo",
        "obnoxio",
        "obrigatorio",
        "obstruir",
        "obtuso",
        "obus",
        "obvio",
        "ocaso",
        "occipital",
        "oceanografo",
        "ocioso",
        "oclusivo",
        "ocorrer",
        "ocre",
        "octogono",
        "odalisca",
        "odisseia",
        "odorifico",
        "oersted",
        "oeste",
        "ofertar",
        "ofidio",
        "oftalmologo",
        "ogiva",
        "ogum",
        "oigale",
        "oitavo",
        "oitocentos",
        "ojeriza",
        "olaria",
        "oleoso",
        "olfato",
        "olhos",
        "oliveira",
        "olmo",
        "olor",
        "olvidavel",
        "ombudsman",
        "omeleteira",
        "omitir",
        "omoplata",
        "onanismo",
        "ondular",
        "oneroso",
        "onomatopeico",
        "ontologico",
        "onus",
        "onze",
        "opalescente",
        "opcional",
        "operistico",
        "opio",
        "oposto",
        "oprobrio",
        "optometrista",
        "opusculo",
        "oratorio",
        "orbital",
        "orcar",
        "orfao",
        "orixa",
        "orla",
        "ornitologo",
        "orquidea",
        "ortorrombico",
        "orvalho",
        "osculo",
        "osmotico",
        "ossudo",
        "ostrogodo",
        "otario",
        "otite",
        "ouro",
        "ousar",
        "outubro",
        "ouvir",
        "ovario",
        "overnight",
        "oviparo",
        "ovni",
        "ovoviviparo",
        "ovulo",
        "oxala",
        "oxente",
        "oxiuro",
        "oxossi",
        "ozonizar",
        "paciente",
        "pactuar",
        "padronizar",
        "paete",
        "pagodeiro",
        "paixao",
        "pajem",
        "paludismo",
        "pampas",
        "panturrilha",
        "papudo",
        "paquistanes",
        "pastoso",
        "patua",
        "paulo",
        "pauzinhos",
        "pavoroso",
        "paxa",
        "pazes",
        "peao",
        "pecuniario",
        "pedunculo",
        "pegaso",
        "peixinho",
        "pejorativo",
        "pelvis",
        "penuria",
        "pequno",
        "petunia",
        "pezada",
        "piauiense",
        "pictorico",
        "pierro",
        "pigmeu",
        "pijama",
        "pilulas",
        "pimpolho",
        "pintura",
        "piorar",
        "pipocar",
        "piqueteiro",
        "pirulito",
        "pistoleiro",
        "pituitaria",
        "pivotar",
        "pixote",
        "pizzaria",
        "plistoceno",
        "plotar",
        "pluviometrico",
        "pneumonico",
        "poco",
        "podridao",
        "poetisa",
        "pogrom",
        "pois",
        "polvorosa",
        "pomposo",
        "ponderado",
        "pontudo",
        "populoso",
        "poquer",
        "porvir",
        "posudo",
        "potro",
        "pouso",
        "povoar",
        "prazo",
        "prezar",
        "privilegios",
        "proximo",
        "prussiano",
        "pseudopode",
        "psoriase",
        "pterossauros",
        "ptialina",
        "ptolemaico",
        "pudor",
        "pueril",
        "pufe",
        "pugilista",
        "puir",
        "pujante",
        "pulverizar",
        "pumba",
        "punk",
        "purulento",
        "pustula",
        "putsch",
        "puxe",
        "quatrocentos",
        "quetzal",
        "quixotesco",
        "quotizavel",
        "rabujice",
        "racista",
        "radonio",
        "rafia",
        "ragu",
        "rajado",
        "ralo",
        "rampeiro",
        "ranzinza",
        "raptor",
        "raquitismo",
        "raro",
        "rasurar",
        "ratoeira",
        "ravioli",
        "razoavel",
        "reavivar",
        "rebuscar",
        "recusavel",
        "reduzivel",
        "reexposicao",
        "refutavel",
        "regurgitar",
        "reivindicavel",
        "rejuvenescimento",
        "relva",
        "remuneravel",
        "renunciar",
        "reorientar",
        "repuxo",
        "requisito",
        "resumo",
        "returno",
        "reutilizar",
        "revolvido",
        "rezonear",
        "riacho",
        "ribossomo",
        "ricota",
        "ridiculo",
        "rifle",
        "rigoroso",
        "rijo",
        "rimel",
        "rins",
        "rios",
        "riqueza",
        "respeito",
        "rissole",
        "ritualistico",
        "rivalizar",
        "rixa",
        "robusto",
        "rococo",
        "rodoviario",
        "roer",
        "rogo",
        "rojao",
        "rolo",
        "rompimento",
        "ronronar",
        "roqueiro",
        "rorqual",
        "rosto",
        "rotundo",
        "rouxinol",
        "roxo",
        "royal",
        "ruas",
        "rucula",
        "rudimentos",
        "ruela",
        "rufo",
        "rugoso",
        "ruivo",
        "rule",
        "rumoroso",
        "runico",
        "ruptura",
        "rural",
        "rustico",
        "rutilar",
        "saariano",
        "sabujo",
        "sacudir",
        "sadomasoquista",
        "safra",
        "sagui",
        "sais",
        "samurai",
        "santuario",
        "sapo",
        "saquear",
        "sartriano",
        "saturno",
        "saude",
        "sauva",
        "saveiro",
        "saxofonista",
        "sazonal",
        "scherzo",
        "script",
        "seara",
        "seborreia",
        "secura",
        "seduzir",
        "sefardim",
        "seguro",
        "seja",
        "selvas",
        "sempre",
        "senzala",
        "sepultura",
        "sequoia",
        "sestercio",
        "setuplo",
        "seus",
        "seviciar",
        "sezonismo",
        "shalom",
        "siames",
        "sibilante",
        "sicrano",
        "sidra",
        "sifilitico",
        "signos",
        "silvo",
        "simultaneo",
        "sinusite",
        "sionista",
        "sirio",
        "sisudo",
        "situar",
        "sivan",
        "slide",
        "slogan",
        "soar",
        "sobrio",
        "socratico",
        "sodomizar",
        "soerguer",
        "software",
        "sogro",
        "soja",
        "solver",
        "somente",
        "sonso",
        "sopro",
        "soquete",
        "sorveteiro",
        "sossego",
        "soturno",
        "sousafone",
        "sovinice",
        "sozinho",
        "suavizar",
        "subverter",
        "sucursal",
        "sudoriparo",
        "sufragio",
        "sugestoes",
        "suite",
        "sujo",
        "sultao",
        "sumula",
        "suntuoso",
        "suor",
        "supurar",
        "suruba",
        "susto",
        "suturar",
        "suvenir",
        "tabuleta",
        "taco",
        "tadjique",
        "tafeta",
        "tagarelice",
        "taitiano",
        "talvez",
        "tampouco",
        "tanzaniano",
        "taoista",
        "tapume",
        "taquion",
        "tarugo",
        "tascar",
        "tatuar",
        "tautologico",
        "tavola",
        "taxionomista",
        "tchecoslovaco",
        "teatrologo",
        "tectonismo",
        "tedioso",
        "teflon",
        "tegumento",
        "teixo",
        "telurio",
        "temporas",
        "tenue",
        "teosofico",
        "tepido",
        "tequila",
        "terrorista",
        "testosterona",
        "tetrico",
        "teutonico",
        "teve",
        "texugo",
        "tiara",
        "tibia",
        "tiete",
        "tifoide",
        "tigresa",
        "tijolo",
        "tilintar",
        "timpano",
        "tintureiro",
        "tiquete",
        "tiroteio",
        "tisico",
        "titulos",
        "tive",
        "toar",
        "toboga",
        "tofu",
        "togoles",
        "toicinho",
        "tolueno",
        "tomografo",
        "tontura",
        "toponimo",
        "toquio",
        "torvelinho",
        "tostar",
        "toto",
        "touro",
        "toxina",
        "trazer",
        "trezentos",
        "trivialidade",
        "trovoar",
        "truta",
        "tuaregue",
        "tubular",
        "tucano",
        "tudo",
        "tufo",
        "tuiste",
        "tulipa",
        "tumultuoso",
        "tunisino",
        "tupiniquim",
        "turvo",
        "tutu",
        "ucraniano",
        "udenista",
        "ufanista",
        "ufologo",
        "ugaritico",
        "uiste",
        "uivo",
        "ulceroso",
        "ulema",
        "ultravioleta",
        "umbilical",
        "umero",
        "umido",
        "umlaut",
        "unanimidade",
        "unesco",
        "ungulado",
        "unheiro",
        "univoco",
        "untuoso",
        "urano",
        "urbano",
        "urdir",
        "uretra",
        "urgente",
        "urinol",
        "urna",
        "urologo",
        "urro",
        "ursulina",
        "urtiga",
        "urupe",
        "usavel",
        "usbeque",
        "usei",
        "usineiro",
        "usurpar",
        "utero",
        "utilizar",
        "utopico",
        "uvular",
        "uxoricidio",
        "vacuo",
        "vadio",
        "vaguear",
        "vaivem",
        "valvula",
        "vampiro",
        "vantajoso",
        "vaporoso",
        "vaquinha",
        "varziano",
        "vasto",
        "vaticinio",
        "vaudeville",
        "vazio",
        "veado",
        "vedico",
        "veemente",
        "vegetativo",
        "veio",
        "veja",
        "veludo",
        "venusiano",
        "verdade",
        "verve",
        "vestuario",
        "vetusto",
        "vexatorio",
        "vezes",
        "viavel",
        "vibratorio",
        "victor",
        "vicunha",
        "vidros",
        "vietnamita",
        "vigoroso",
        "vilipendiar",
        "vime",
        "vintem",
        "violoncelo",
        "viquingue",
        "virus",
        "visualizar",
        "vituperio",
        "viuvo",
        "vivo",
        "vizir",
        "voar",
        "vociferar",
        "vodu",
        "vogar",
        "voile",
        "volver",
        "vomito",
        "vontade",
        "vortice",
        "vosso",
        "voto",
        "vovozinha",
        "voyeuse",
        "vozes",
        "vulva",
        "vupt",
        "western",
        "xadrez",
        "xale",
        "xampu",
        "xango",
        "xarope",
        "xaual",
        "xavante",
        "xaxim",
        "xenonio",
        "xepa",
        "xerox",
        "xicara",
        "xifopago",
        "xiita",
        "xilogravura",
        "xinxim",
        "xistoso",
        "xixi",
        "xodo",
        "xogum",
        "xucro",
        "zabumba",
        "zagueiro",
        "zambiano",
        "zanzar",
        "zarpar",
        "zebu",
        "zefiro",
        "zeloso",
        "zenite",
        "zumbi"
    ]



from __future__ import unicode_literals
import binascii
from datetime import datetime
import operator
import json
import logging
import requests
import six

from .. import exceptions
from ..account import Account
from ..address import address, Address, SubAddress
from ..block import Block
from ..const import NET_MAIN, NET_TEST, NET_STAGE
from ..numbers import from_atomic, to_atomic, PaymentID
from ..seed import Seed
from ..transaction import Transaction, IncomingPayment, OutgoingPayment


_log = logging.getLogger(__name__)


RESTRICTED_MAX_TRANSACTIONS = 100


class JSONRPCDaemon(object):
    """
    JSON RPC backend for Monero daemon

    :param protocol: `http` or `https`
    :param host: host name or IP
    :param port: port number
    :param path: path for JSON RPC requests (should not be changed)
    :param timeout: request timeout
    :param verify_ssl_certs: verify SSL certificates when connecting
    :param proxy_url: a proxy to use
    """

    _net = None

    def __init__(self, protocol='http', host='127.0.0.1', port=18081, path='/json_rpc',
            user='', password='', timeout=30, verify_ssl_certs=True, proxy_url=None):
        self.url = '{protocol}://{host}:{port}'.format(
                protocol=protocol,
                host=host,
                port=port)
        _log.debug("JSONRPC daemon backend URL: {url}".format(url=self.url))
        self.user = user
        self.password = password
        self.timeout = timeout
        self.verify_ssl_certs = verify_ssl_certs
        self.proxies = {protocol: proxy_url}

    def _set_net(self, info):
        if info['mainnet']:
            self._net = NET_MAIN
        if info['testnet']:
            self._net = NET_TEST
        if info['stagenet']:
            self._net = NET_STAGE

    def info(self):
        info = self.raw_jsonrpc_request('get_info')
        self._set_net(info)
        return info

    def net(self):
        if self._net:
            return self._net
        self.info()
        return self._net

    def send_transaction(self, blob, relay=True):
        res = self.raw_request('/sendrawtransaction', {
            'tx_as_hex': six.ensure_text(binascii.hexlify(blob)),
            'do_not_relay': not relay})
        if res['status'] == 'OK':
            return res
        raise exceptions.TransactionBroadcastError(
                "{status}: {reason}".format(**res),
                details=res)

    def mempool(self):
        res = self.raw_request('/get_transaction_pool', {})
        txs = []
        for tx in res.get('transactions', []):
            txs.append(Transaction(
                hash=tx['id_hash'],
                fee=from_atomic(tx['fee']),
                timestamp=datetime.fromtimestamp(tx['receive_time']),
                blob=binascii.unhexlify(tx['tx_blob']),
                json=json.loads(tx['tx_json']),
                confirmations=0))
        return txs

    def headers(self, start_height, end_height=None):
        end_height = end_height or start_height
        res = self.raw_jsonrpc_request('get_block_headers_range', {
                'start_height': start_height,
                'end_height': end_height})
        if res['status'] == 'OK':
            return res['headers']
        raise exceptions.BackendException(res['status'])

    def block(self, bhash=None, height=None):
        data = {}
        if bhash:
            data['hash'] = bhash
        if height:
            data['height'] = height
        res = self.raw_jsonrpc_request('get_block', data)
        if res['status'] == 'OK':
            bhdr = res['block_header']
            sub_json = json.loads(res['json'])
            data = {
                'blob': res['blob'],
                'hash': bhdr['hash'],
                'height': bhdr['height'],
                'timestamp': datetime.fromtimestamp(bhdr['timestamp']),
                'version': (bhdr['major_version'], bhdr['minor_version']),
                'difficulty': bhdr['difficulty'],
                'nonce': bhdr['nonce'],
                'orphan': bhdr['orphan_status'],
                'prev_hash': bhdr['prev_hash'],
                'reward': from_atomic(bhdr['reward']),
                'transactions': self.transactions(
                    [bhdr['miner_tx_hash']] + sub_json['tx_hashes']),
            }
            return Block(**data)
        raise exceptions.BackendException(res['status'])

    def transactions(self, hashes):
        """
        Returns a list of transactions for given hashes. Automatically chunks the request
        into amounts acceptable by a restricted RPC server.
        """
        hashes = list(hashes)
        result = []
        while len(hashes):
            result.extend(self._do_get_transactions(hashes[:RESTRICTED_MAX_TRANSACTIONS]))
            hashes = hashes[RESTRICTED_MAX_TRANSACTIONS:]
        return result

    def _do_get_transactions(self, hashes):
        res = self.raw_request('/get_transactions', {
                'txs_hashes': hashes,
                'decode_as_json': True})
        if res['status'] != 'OK':
            raise exceptions.BackendException(res['status'])
        txs = []
        for tx in res.get('txs', []):
            as_json = json.loads(tx['as_json'])
            fee = as_json.get('rct_signatures', {}).get('txnFee')
            txs.append(Transaction(
                hash=tx['tx_hash'],
                fee=from_atomic(fee) if fee else None,
                height=None if tx['in_pool'] else tx['block_height'],
                timestamp=datetime.fromtimestamp(
                    tx['block_timestamp']) if 'block_timestamp' in tx else None,
                blob=binascii.unhexlify(tx['as_hex']),
                json=as_json))
        return txs

    def raw_request(self, path, data):
        hdr = {'Content-Type': 'application/json'}
        _log.debug(u"Request: {path}\nData: {data}".format(
            path=path,
            data=json.dumps(data, indent=2, sort_keys=True)))
        auth = requests.auth.HTTPDigestAuth(self.user, self.password)
        rsp = requests.post(
            self.url + path, headers=hdr, data=json.dumps(data), auth=auth,
            timeout=self.timeout, verify=self.verify_ssl_certs, proxies=self.proxies)
        if rsp.status_code != 200:
            raise RPCError("Invalid HTTP status {code} for path {path}.".format(
                code=rsp.status_code,
                path=path))
        result = rsp.json()
        _ppresult = json.dumps(result, indent=2, sort_keys=True)
        _log.debug(u"Result:\n{result}".format(result=_ppresult))
        return result

    def raw_jsonrpc_request(self, method, params=None):
        hdr = {'Content-Type': 'application/json'}
        data = {'jsonrpc': '2.0', 'id': 0, 'method': method, 'params': params or {}}
        _log.debug(u"Method: {method}\nParams:\n{params}".format(
            method=method,
            params=json.dumps(params, indent=2, sort_keys=True)))
        auth = requests.auth.HTTPDigestAuth(self.user, self.password)
        rsp = requests.post(
            self.url + '/json_rpc', headers=hdr, data=json.dumps(data), auth=auth,
            timeout=self.timeout, verify=self.verify_ssl_certs, proxies=self.proxies)

        if rsp.status_code == 401:
            raise Unauthorized("401 Unauthorized. Invalid RPC user name or password.")
        elif rsp.status_code != 200:
            raise RPCError("Invalid HTTP status {code} for method {method}.".format(
                code=rsp.status_code,
                method=method))
        result = rsp.json()
        _ppresult = json.dumps(result, indent=2, sort_keys=True)
        _log.debug(u"Result:\n{result}".format(result=_ppresult))

        if 'error' in result:
            err = result['error']
            _log.error(u"JSON RPC error:\n{result}".format(result=_ppresult))
            raise RPCError(
                "Method '{method}' failed with RPC Error of unknown code {code}, "
                "message: {message}".format(method=method, data=data, result=result, **err))
        return result['result']


class JSONRPCWallet(object):
    """
    JSON RPC backend for Monero wallet (``monero-wallet-rpc``)

    :param protocol: `http` or `https`
    :param host: host name or IP
    :param port: port number
    :param path: path for JSON RPC requests (should not be changed)
    :param user: username to authenticate with over RPC
    :param password: password to authenticate with over RPC
    :param timeout: request timeout
    :param verify_ssl_certs: verify ssl certs for request
    :param proxy_url: a proxy to use
    """
    _master_address = None

    def __init__(self, protocol='http', host='127.0.0.1', port=18088, path='/json_rpc',
            user='', password='', timeout=30, verify_ssl_certs=True, proxy_url=None):
        self.url = '{protocol}://{host}:{port}/json_rpc'.format(
                protocol=protocol,
                host=host,
                port=port)
        _log.debug("JSONRPC wallet backend URL: {url}".format(url=self.url))
        self.user = user
        self.password = password
        self.timeout = timeout
        self.verify_ssl_certs = verify_ssl_certs
        self.proxies = {protocol: proxy_url}
        _log.debug("JSONRPC wallet backend auth: '{user}'/'{stars}'".format(
            user=user, stars=('*' * len(password)) if password else ''))

    def height(self):
        return self.raw_request('getheight')['height']

    def spend_key(self):
        return self.raw_request('query_key', {'key_type': 'spend_key'})['key']

    def view_key(self):
        return self.raw_request('query_key', {'key_type': 'view_key'})['key']

    def seed(self):
        return Seed(self.raw_request('query_key', {'key_type': 'mnemonic'})['key'])

    def accounts(self):
        accounts = []
        _accounts = self.raw_request('get_accounts')
        idx = 0
        self._master_address = Address(_accounts['subaddress_accounts'][0]['base_address'])
        for _acc in _accounts['subaddress_accounts']:
            assert idx == _acc['account_index']
            accounts.append(Account(self, _acc['account_index'], label=_acc.get('label')))
            idx += 1
        return accounts

    def new_account(self, label=None):
        _account = self.raw_request('create_account', {'label': label})
        # NOTE: the following should re-read label by _account.get('label') but the RPC
        # doesn't return that detail here
        return Account(self, _account['account_index'], label=label), SubAddress(_account['address'])

    def addresses(self, account=0, addr_indices=None):
        qdata = {'account_index': account}
        if addr_indices:
            qdata['address_index'] = addr_indices
        _addresses = self.raw_request('getaddress', qdata)
        addresses = [None] * (max(map(operator.itemgetter('address_index'), _addresses['addresses'])) + 1)
        for _addr in _addresses['addresses']:
            addresses[_addr['address_index']] = address(
                _addr['address'],
                label=_addr.get('label', None))
        return addresses

    def new_address(self, account=0, label=None):
        _address = self.raw_request(
            'create_address', {'account_index': account, 'label': label})
        return SubAddress(_address['address']), _address['address_index']

    def balances(self, account=0):
        _balance = self.raw_request('getbalance', {'account_index': account})
        return (from_atomic(_balance['balance']), from_atomic(_balance['unlocked_balance']))

    def transfers_in(self, account, pmtfilter):
        params = {'account_index': account, 'pending': False}
        method = 'get_transfers'
        if pmtfilter.tx_ids:
            method = 'get_transfer_by_txid'
        if pmtfilter.unconfirmed:
            params['in'] = pmtfilter.confirmed
            params['out'] = False
            params['pool'] = True
        else:
            if pmtfilter.payment_ids:
                method = 'get_bulk_payments'
                params['payment_ids'] = list(map(str, pmtfilter.payment_ids))
            else:
                params['in'] = pmtfilter.confirmed
                params['out'] = False
                params['pool'] = False
        if method == 'get_transfers':
            if pmtfilter.min_height:
                # NOTE: the API uses (min, max] range which is confusing
                params['min_height'] = pmtfilter.min_height - 1
                params['filter_by_height'] = True
            if pmtfilter.max_height:
                params['max_height'] = pmtfilter.max_height
                params['filter_by_height'] = True
            _pmts = self.raw_request(method, params)
            pmts = _pmts.get('in', [])
        elif method == 'get_transfer_by_txid':
            pmts = []
            for txid in pmtfilter.tx_ids:
                params['txid'] = txid
                try:
                    _pmts = self.raw_request(method, params, squelch_error_logging=True)
                except exceptions.TransactionNotFound:
                    continue
                pmts.extend(_pmts['transfers'])
                # Issue #71: incoming payments to self will have excess 'destinations' key. Remove.
                for pmt in pmts:
                    try:
                        del pmt['destinations']
                    except KeyError:
                        pass
        else:
            # NOTE: the API uses (min, max] range which is confusing
            params['min_block_height'] = (pmtfilter.min_height or 1) - 1
            _pmts = self.raw_request(method, params)
            pmts = _pmts.get('payments', [])
        if pmtfilter.unconfirmed:
            pmts.extend(_pmts.get('pool', []))
        return list(pmtfilter.filter(map(self._inpayment, pmts)))

    def transfers_out(self, account, pmtfilter):
        if pmtfilter.tx_ids:
            pmts = []
            for txid in pmtfilter.tx_ids:
                try:
                    _pmts = self.raw_request(
                        'get_transfer_by_txid',
                        {'account_index': account, 'txid': txid},
                        squelch_error_logging=True)
                except exceptions.TransactionNotFound:
                    continue
                pmts.extend(_pmts['transfers'])
        else:
            _pmts = self.raw_request('get_transfers', {
                'account_index': account,
                'in': False,
                'out': pmtfilter.confirmed,
                'pool': False,
                'pending': pmtfilter.unconfirmed})
            pmts = _pmts.get('out', [])
            if pmtfilter.unconfirmed:
                pmts.extend(_pmts.get('pending', []))
        return list(pmtfilter.filter(map(self._outpayment, pmts)))

    def _paymentdict(self, data):
        pid = data.get('payment_id', None)
        laddr = data.get('address', None)
        if laddr:
            laddr = address(laddr)
        result = {
            'payment_id': None if pid is None else PaymentID(pid),
            'amount': from_atomic(data['amount']),
            'timestamp': datetime.fromtimestamp(data['timestamp']) if 'timestamp' in data else None,
            'note': data.get('note', None),
            'transaction': self._tx(data),
            'local_address': laddr,
        }
        if 'destinations' in data:
            result['destinations'] = [
                (address(x['address']), from_atomic(x['amount']))
                for x in data.get('destinations')
            ]
        return result


    def _inpayment(self, data):
        return IncomingPayment(**self._paymentdict(data))

    def _outpayment(self, data):
        return OutgoingPayment(**self._paymentdict(data))

    def _tx(self, data):
        return Transaction(**{
            'hash': data.get('txid', data.get('tx_hash')),
            'fee': from_atomic(data['fee']) if 'fee' in data else None,
            'key': data.get('key'),
            'height': data.get('height', data.get('block_height')) or None,
            'timestamp': datetime.fromtimestamp(data['timestamp']) if 'timestamp' in data else None,
            'blob': binascii.unhexlify(data.get('blob', '')),
            'confirmations': data.get('confirmations', None)
        })

    def export_outputs(self):
        return self.raw_request('export_outputs')['outputs_data_hex']

    def import_outputs(self, outputs_hex):
        return self.raw_request(
            'import_outputs',
            {'outputs_data_hex': outputs_hex})['num_imported']

    def export_key_images(self):
        return self.raw_request('export_key_images')['signed_key_images']

    def import_key_images(self, key_images):
        _data = self.raw_request(
            'import_key_images',
            {'signed_key_images': key_images})
        return (_data['height'], from_atomic(_data['spent']), from_atomic(_data['unspent']))

    def transfer(self, destinations, priority,
            payment_id=None, unlock_time=0, account=0,
            relay=True):
        data = {
            'account_index': account,
            'destinations': list(map(
                lambda dst: {'address': str(address(dst[0])), 'amount': to_atomic(dst[1])},
                destinations)),
            'priority': priority,
            'unlock_time': 0,
            'get_tx_keys': True,
            'get_tx_hex': True,
            'new_algorithm': True,
            'do_not_relay': not relay,
        }
        if payment_id is not None:
            data['payment_id'] = str(PaymentID(payment_id))
        _transfers = self.raw_request('transfer_split', data)
        _pertx = [dict(_tx) for _tx in map(
            lambda vs: zip(('txid', 'amount', 'fee', 'key', 'blob', 'payment_id'), vs),
            zip(*[_transfers[k] for k in (
                'tx_hash_list', 'amount_list', 'fee_list', 'tx_key_list', 'tx_blob_list')]))]
        for d in _pertx:
            d['payment_id'] = payment_id
        return [self._tx(data) for data in _pertx]

    def sweep_all(self, destination, priority, payment_id=None, subaddr_indices=None,
            unlock_time=0, account=0, relay=True):
        if not subaddr_indices:
            # retrieve indices of all subaddresses with positive unlocked balance
            bals = self.raw_request('get_balance', {'account_index': account})
            subaddr_indices = []
            for subaddr in bals['per_subaddress']:
                if subaddr.get('unlocked_balance', 0):
                    subaddr_indices.append(subaddr['address_index'])
        data = {
            'account_index': account,
            'address': str(address(destination)),
            'subaddr_indices': list(subaddr_indices),
            'priority': priority,
            'unlock_time': 0,
            'get_tx_keys': True,
            'get_tx_hex': True,
            'do_not_relay': not relay,
        }
        if payment_id is not None:
            data['payment_id'] = str(PaymentID(payment_id))
        _transfers = self.raw_request('sweep_all', data)
        _pertx = [dict(_tx) for _tx in map(
            lambda vs: zip(('txid', 'amount', 'fee', 'key', 'blob', 'payment_id'), vs),
            zip(*[_transfers[k] for k in (
                'tx_hash_list', 'amount_list', 'fee_list', 'tx_key_list', 'tx_blob_list')]))]
        for d in _pertx:
            d['payment_id'] = payment_id
        return list(zip(
                [self._tx(data) for data in _pertx],
                map(from_atomic, _transfers['amount_list'])))

    def raw_request(self, method, params=None, squelch_error_logging=False):
        hdr = {'Content-Type': 'application/json'}
        data = {'jsonrpc': '2.0', 'id': 0, 'method': method, 'params': params or {}}
        _log.debug(u"Method: {method}\nParams:\n{params}".format(
            method=method,
            params=json.dumps(params, indent=2, sort_keys=True)))
        auth = requests.auth.HTTPDigestAuth(self.user, self.password)
        rsp = requests.post(
            self.url, headers=hdr, data=json.dumps(data), auth=auth,
            timeout=self.timeout, verify=self.verify_ssl_certs, proxies=self.proxies)

        if rsp.status_code == 401:
            raise Unauthorized("401 Unauthorized. Invalid RPC user name or password.")
        elif rsp.status_code != 200:
            raise RPCError("Invalid HTTP status {code} for method {method}.".format(
                code=rsp.status_code,
                method=method))
        result = rsp.json()
        _ppresult = json.dumps(result, indent=2, sort_keys=True)
        _log.debug(u"Result:\n{result}".format(result=_ppresult))

        if 'error' in result:
            err = result['error']
            if not squelch_error_logging:
                _log.error(u"JSON RPC error:\n{result}".format(result=_ppresult))
            if err['code'] in _err2exc:
                raise _err2exc[err['code']](err['message'])
            else:
                raise RPCError(
                    "Method '{method}' failed with RPC Error of unknown code {code}, "
                    "message: {message}".format(method=method, data=data, result=result, **err))
        return result['result']


class RPCError(exceptions.BackendException):
    pass


class Unauthorized(RPCError):
    pass


class MethodNotFound(RPCError):
    pass


_err2exc = {
    -2: exceptions.WrongAddress,
    -4: exceptions.GenericTransferError,
    -5: exceptions.WrongPaymentId,
    -8: exceptions.TransactionNotFound,
    -9: exceptions.SignatureCheckFailed,
    -14: exceptions.AccountIndexOutOfBound,
    -15: exceptions.AddressIndexOutOfBound,
    -16: exceptions.TransactionNotPossible,
    -17: exceptions.NotEnoughMoney,
    -20: exceptions.AmountIsZero,
    -29: exceptions.WalletIsWatchOnly,
    -37: exceptions.NotEnoughUnlockedMoney,
    -38: exceptions.NoDaemonConnection,
    -43: exceptions.WalletIsNotDeterministic, # https://github.com/monero-project/monero/pull/4653
    -32601: MethodNotFound,
}



from binascii import hexlify, unhexlify
import re
from sha3 import keccak_256
import six
import struct
import warnings

from . import base58
from . import const
from . import ed25519
from . import numbers

_ADDR_REGEX = re.compile(r'^[123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz]{95}$')
_IADDR_REGEX = re.compile(r'^[123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz]{106}$')

class BaseAddress(object):
    label = None

    def __init__(self, addr, label=None):
        addr = addr.decode() if isinstance(addr, bytes) else str(addr)
        if not _ADDR_REGEX.match(addr):
            raise ValueError("Address must be 95 characters long base58-encoded string, "
                "is {addr} ({len} chars length)".format(addr=addr, len=len(addr)))
        self._decode(addr)
        self.label = label or self.label

    def view_key(self):
        """Returns public view key.

        :rtype: str
        """
        return hexlify(self._decoded[33:65]).decode()

    def spend_key(self):
        """Returns public spend key.

        :rtype: str
        """
        return hexlify(self._decoded[1:33]).decode()

    @property
    def net(self):
        return const.NETS[self._valid_netbytes.index(self._decoded[0])]

    def is_mainnet(self):
        """Returns `True` if the address belongs to mainnet.

        :rtype: bool
        """
        warnings.warn(".is_mainnet(), .is_testnet() and .is_stagenet() methods are deprecated "
            "and will be gone in 0.8; use Address.net property and constants form monero.const "
            "instead",
            DeprecationWarning)
        return self.net == const.NET_MAIN

    def is_testnet(self):
        """Returns `True` if the address belongs to testnet.

        :rtype: bool
        """
        warnings.warn(".is_mainnet(), .is_testnet() and .is_stagenet() methods are deprecated "
            "and will be gone in 0.8; use Address.net property and constants form monero.const "
            "instead",
            DeprecationWarning)
        return self.net == const.NET_TEST

    def is_stagenet(self):
        """Returns `True` if the address belongs to stagenet.

        :rtype: bool
        """
        warnings.warn(".is_mainnet(), .is_testnet() and .is_stagenet() methods are deprecated "
            "and will be gone in 0.8; use Address.net property and constants form monero.const "
            "instead",
            DeprecationWarning)
        return self.net == const.NET_STAGE

    def _decode(self, address):
        self._decoded = bytearray(unhexlify(base58.decode(address)))
        checksum = self._decoded[-4:]
        if checksum != keccak_256(self._decoded[:-4]).digest()[:4]:
            raise ValueError("Invalid checksum in address {}".format(address))
        if self._decoded[0] not in self._valid_netbytes:
            raise ValueError("Invalid address netbyte {nb}. Allowed values are: {allowed}".format(
                nb=self._decoded[0],
                allowed=", ".join(map(lambda b: '%02x' % b, self._valid_netbytes))))

    def __repr__(self):
        return base58.encode(hexlify(self._decoded))

    def __eq__(self, other):
        if isinstance(other, BaseAddress):
            return str(self) == str(other)
        elif isinstance(other, six.text_type) or isinstance(other, six.string_types):
            return str(self) == six.ensure_str(other)
        return super(BaseAddress, self).__eq__(other)

    def __hash__(self):
        return hash(str(self))

    def __format__(self, spec):
        return format(str(self), spec)


class Address(BaseAddress):
    """Monero address.

    Address of this class is the master address for a :class:`Wallet <monero.wallet.Wallet>`.

    :param address: a Monero address as string-like object
    :param label: a label for the address (defaults to `None`)
    """
    _valid_netbytes = const.MASTERADDR_NETBYTES

    def check_private_view_key(self, key):
        """Checks if private view key matches this address.

        :rtype: bool
        """
        return ed25519.public_from_secret_hex(key) == self.view_key()

    def check_private_spend_key(self, key):
        """Checks if private spend key matches this address.

        :rtype: bool
        """
        return ed25519.public_from_secret_hex(key) == self.spend_key()

    def with_payment_id(self, payment_id=0):
        """Integrates payment id into the address.

        :param payment_id: int, hexadecimal string or :class:`PaymentID <monero.numbers.PaymentID>`
                    (max 64-bit long)

        :rtype: `IntegratedAddress`
        :raises: `TypeError` if the payment id is too long
        """
        payment_id = numbers.PaymentID(payment_id)
        if not payment_id.is_short():
            raise TypeError("Payment ID {0} has more than 64 bits and cannot be integrated".format(payment_id))
        prefix = const.INTADDRR_NETBYTES[const.NETS.index(self.net)]
        data = bytearray([prefix]) + self._decoded[1:65] + struct.pack('>Q', int(payment_id))
        checksum = bytearray(keccak_256(data).digest()[:4])
        return IntegratedAddress(base58.encode(hexlify(data + checksum)))


class SubAddress(BaseAddress):
    """Monero subaddress.

    Any type of address which is not the master one for a wallet.
    """

    _valid_netbytes = const.SUBADDR_NETBYTES

    def with_payment_id(self, _):
        raise TypeError("SubAddress cannot be integrated with payment ID")


class IntegratedAddress(Address):
    """Monero integrated address.

    A master address integrated with payment id (short one, max 64 bit).
    """

    _valid_netbytes = const.INTADDRR_NETBYTES

    def __init__(self, address):
        address = address.decode() if isinstance(address, bytes) else str(address)
        if not _IADDR_REGEX.match(address):
            raise ValueError("Integrated address must be 106 characters long base58-encoded string, "
                "is {addr} ({len} chars length)".format(addr=address, len=len(address)))
        self._decode(address)

    def payment_id(self):
        """Returns the integrated payment id.

        :rtype: :class:`PaymentID <monero.numbers.PaymentID>`
        """
        return numbers.PaymentID(hexlify(self._decoded[65:-4]).decode())

    def base_address(self):
        """Returns the base address without payment id.
        :rtype: :class:`Address`
        """
        prefix = const.MASTERADDR_NETBYTES[const.NETS.index(self.net)]
        data = bytearray([prefix]) + self._decoded[1:65]
        checksum = keccak_256(data).digest()[:4]
        return Address(base58.encode(hexlify(data + checksum)))


def address(addr, label=None):
    """Discover the proper class and return instance for a given Monero address.

    :param addr: the address as a string-like object
    :param label: a label for the address (defaults to `None`)

    :rtype: :class:`Address`, :class:`SubAddress` or :class:`IntegratedAddress`
    """
    addr = addr.decode() if isinstance(addr, bytes) else str(addr)
    if _ADDR_REGEX.match(addr):
        netbyte = bytearray(unhexlify(base58.decode(addr)))[0]
        if netbyte in Address._valid_netbytes:
            return Address(addr, label=label)
        elif netbyte in SubAddress._valid_netbytes:
            return SubAddress(addr, label=label)
        raise ValueError("Invalid address netbyte {nb:x}. Allowed values are: {allowed}".format(
            nb=netbyte,
            allowed=", ".join(map(
                lambda b: '%02x' % b,
                sorted(Address._valid_netbytes + SubAddress._valid_netbytes)))))
    elif _IADDR_REGEX.match(addr):
        return IntegratedAddress(addr)
    raise ValueError("Address must be either 95 or 106 characters long base58-encoded string, "
        "is {addr} ({len} chars length)".format(addr=addr, len=len(addr)))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Word list originally created by dabura667 and released under The MIT License (MIT)
#
# The MIT License (MIT)
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
# Code surrounding the word list is Copyright (c) 2014-2018, The Monero Project
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this list of
#    conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice, this list
#    of conditions and the following disclaimer in the documentation and/or other
#    materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its contributors may be
#    used to endorse or promote products derived from this software without specific
#    prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
# THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
# THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# list of words from:
#     https://github.com/monero-project/monero/blob/master/src/mnemonics/russian.h
#     Most recent commit: 8ea3c4d54429976e9001b8cc4868b721e6747e3c


from .wordlist import Wordlist


class Russian(Wordlist):
    language_name = u"русский язык"
    english_language_name = "Russian"
    unique_prefix_length = 4
    word_list = [
        u"абажур",
        u"абзац",
        u"абонент",
        u"абрикос",
        u"абсурд",
        u"авангард",
        u"август",
        u"авиация",
        u"авоська",
        u"автор",
        u"агат",
        u"агент",
        u"агитатор",
        u"агнец",
        u"агония",
        u"агрегат",
        u"адвокат",
        u"адмирал",
        u"адрес",
        u"ажиотаж",
        u"азарт",
        u"азбука",
        u"азот",
        u"аист",
        u"айсберг",
        u"академия",
        u"аквариум",
        u"аккорд",
        u"акробат",
        u"аксиома",
        u"актер",
        u"акула",
        u"акция",
        u"алгоритм",
        u"алебарда",
        u"аллея",
        u"алмаз",
        u"алтарь",
        u"алфавит",
        u"алхимик",
        u"алый",
        u"альбом",
        u"алюминий",
        u"амбар",
        u"аметист",
        u"амнезия",
        u"ампула",
        u"амфора",
        u"анализ",
        u"ангел",
        u"анекдот",
        u"анимация",
        u"анкета",
        u"аномалия",
        u"ансамбль",
        u"антенна",
        u"апатия",
        u"апельсин",
        u"апофеоз",
        u"аппарат",
        u"апрель",
        u"аптека",
        u"арабский",
        u"арбуз",
        u"аргумент",
        u"арест",
        u"ария",
        u"арка",
        u"армия",
        u"аромат",
        u"арсенал",
        u"артист",
        u"архив",
        u"аршин",
        u"асбест",
        u"аскетизм",
        u"аспект",
        u"ассорти",
        u"астроном",
        u"асфальт",
        u"атака",
        u"ателье",
        u"атлас",
        u"атом",
        u"атрибут",
        u"аудитор",
        u"аукцион",
        u"аура",
        u"афера",
        u"афиша",
        u"ахинея",
        u"ацетон",
        u"аэропорт",
        u"бабушка",
        u"багаж",
        u"бадья",
        u"база",
        u"баклажан",
        u"балкон",
        u"бампер",
        u"банк",
        u"барон",
        u"бассейн",
        u"батарея",
        u"бахрома",
        u"башня",
        u"баян",
        u"бегство",
        u"бедро",
        u"бездна",
        u"бекон",
        u"белый",
        u"бензин",
        u"берег",
        u"беседа",
        u"бетонный",
        u"биатлон",
        u"библия",
        u"бивень",
        u"бигуди",
        u"бидон",
        u"бизнес",
        u"бикини",
        u"билет",
        u"бинокль",
        u"биология",
        u"биржа",
        u"бисер",
        u"битва",
        u"бицепс",
        u"благо",
        u"бледный",
        u"близкий",
        u"блок",
        u"блуждать",
        u"блюдо",
        u"бляха",
        u"бобер",
        u"богатый",
        u"бодрый",
        u"боевой",
        u"бокал",
        u"большой",
        u"борьба",
        u"босой",
        u"ботинок",
        u"боцман",
        u"бочка",
        u"боярин",
        u"брать",
        u"бревно",
        u"бригада",
        u"бросать",
        u"брызги",
        u"брюки",
        u"бублик",
        u"бугор",
        u"будущее",
        u"буква",
        u"бульвар",
        u"бумага",
        u"бунт",
        u"бурный",
        u"бусы",
        u"бутылка",
        u"буфет",
        u"бухта",
        u"бушлат",
        u"бывалый",
        u"быль",
        u"быстрый",
        u"быть",
        u"бюджет",
        u"бюро",
        u"бюст",
        u"вагон",
        u"важный",
        u"ваза",
        u"вакцина",
        u"валюта",
        u"вампир",
        u"ванная",
        u"вариант",
        u"вассал",
        u"вата",
        u"вафля",
        u"вахта",
        u"вдова",
        u"вдыхать",
        u"ведущий",
        u"веер",
        u"вежливый",
        u"везти",
        u"веко",
        u"великий",
        u"вена",
        u"верить",
        u"веселый",
        u"ветер",
        u"вечер",
        u"вешать",
        u"вещь",
        u"веяние",
        u"взаимный",
        u"взбучка",
        u"взвод",
        u"взгляд",
        u"вздыхать",
        u"взлетать",
        u"взмах",
        u"взнос",
        u"взор",
        u"взрыв",
        u"взывать",
        u"взятка",
        u"вибрация",
        u"визит",
        u"вилка",
        u"вино",
        u"вирус",
        u"висеть",
        u"витрина",
        u"вихрь",
        u"вишневый",
        u"включать",
        u"вкус",
        u"власть",
        u"влечь",
        u"влияние",
        u"влюблять",
        u"внешний",
        u"внимание",
        u"внук",
        u"внятный",
        u"вода",
        u"воевать",
        u"вождь",
        u"воздух",
        u"войти",
        u"вокзал",
        u"волос",
        u"вопрос",
        u"ворота",
        u"восток",
        u"впадать",
        u"впускать",
        u"врач",
        u"время",
        u"вручать",
        u"всадник",
        u"всеобщий",
        u"вспышка",
        u"встреча",
        u"вторник",
        u"вулкан",
        u"вурдалак",
        u"входить",
        u"въезд",
        u"выбор",
        u"вывод",
        u"выгодный",
        u"выделять",
        u"выезжать",
        u"выживать",
        u"вызывать",
        u"выигрыш",
        u"вылезать",
        u"выносить",
        u"выпивать",
        u"высокий",
        u"выходить",
        u"вычет",
        u"вышка",
        u"выяснять",
        u"вязать",
        u"вялый",
        u"гавань",
        u"гадать",
        u"газета",
        u"гаишник",
        u"галстук",
        u"гамма",
        u"гарантия",
        u"гастроли",
        u"гвардия",
        u"гвоздь",
        u"гектар",
        u"гель",
        u"генерал",
        u"геолог",
        u"герой",
        u"гешефт",
        u"гибель",
        u"гигант",
        u"гильза",
        u"гимн",
        u"гипотеза",
        u"гитара",
        u"глаз",
        u"глина",
        u"глоток",
        u"глубокий",
        u"глыба",
        u"глядеть",
        u"гнать",
        u"гнев",
        u"гнить",
        u"гном",
        u"гнуть",
        u"говорить",
        u"годовой",
        u"голова",
        u"гонка",
        u"город",
        u"гость",
        u"готовый",
        u"граница",
        u"грех",
        u"гриб",
        u"громкий",
        u"группа",
        u"грызть",
        u"грязный",
        u"губа",
        u"гудеть",
        u"гулять",
        u"гуманный",
        u"густой",
        u"гуща",
        u"давать",
        u"далекий",
        u"дама",
        u"данные",
        u"дарить",
        u"дать",
        u"дача",
        u"дверь",
        u"движение",
        u"двор",
        u"дебют",
        u"девушка",
        u"дедушка",
        u"дежурный",
        u"дезертир",
        u"действие",
        u"декабрь",
        u"дело",
        u"демократ",
        u"день",
        u"депутат",
        u"держать",
        u"десяток",
        u"детский",
        u"дефицит",
        u"дешевый",
        u"деятель",
        u"джаз",
        u"джинсы",
        u"джунгли",
        u"диалог",
        u"диван",
        u"диета",
        u"дизайн",
        u"дикий",
        u"динамика",
        u"диплом",
        u"директор",
        u"диск",
        u"дитя",
        u"дичь",
        u"длинный",
        u"дневник",
        u"добрый",
        u"доверие",
        u"договор",
        u"дождь",
        u"доза",
        u"документ",
        u"должен",
        u"домашний",
        u"допрос",
        u"дорога",
        u"доход",
        u"доцент",
        u"дочь",
        u"дощатый",
        u"драка",
        u"древний",
        u"дрожать",
        u"друг",
        u"дрянь",
        u"дубовый",
        u"дуга",
        u"дудка",
        u"дукат",
        u"дуло",
        u"думать",
        u"дупло",
        u"дурак",
        u"дуть",
        u"духи",
        u"душа",
        u"дуэт",
        u"дымить",
        u"дыня",
        u"дыра",
        u"дыханье",
        u"дышать",
        u"дьявол",
        u"дюжина",
        u"дюйм",
        u"дюна",
        u"дядя",
        u"дятел",
        u"егерь",
        u"единый",
        u"едкий",
        u"ежевика",
        u"ежик",
        u"езда",
        u"елка",
        u"емкость",
        u"ерунда",
        u"ехать",
        u"жадный",
        u"жажда",
        u"жалеть",
        u"жанр",
        u"жара",
        u"жать",
        u"жгучий",
        u"ждать",
        u"жевать",
        u"желание",
        u"жемчуг",
        u"женщина",
        u"жертва",
        u"жесткий",
        u"жечь",
        u"живой",
        u"жидкость",
        u"жизнь",
        u"жилье",
        u"жирный",
        u"житель",
        u"журнал",
        u"жюри",
        u"забывать",
        u"завод",
        u"загадка",
        u"задача",
        u"зажечь",
        u"зайти",
        u"закон",
        u"замечать",
        u"занимать",
        u"западный",
        u"зарплата",
        u"засыпать",
        u"затрата",
        u"захват",
        u"зацепка",
        u"зачет",
        u"защита",
        u"заявка",
        u"звать",
        u"звезда",
        u"звонить",
        u"звук",
        u"здание",
        u"здешний",
        u"здоровье",
        u"зебра",
        u"зевать",
        u"зеленый",
        u"земля",
        u"зенит",
        u"зеркало",
        u"зефир",
        u"зигзаг",
        u"зима",
        u"зиять",
        u"злак",
        u"злой",
        u"змея",
        u"знать",
        u"зной",
        u"зодчий",
        u"золотой",
        u"зомби",
        u"зона",
        u"зоопарк",
        u"зоркий",
        u"зрачок",
        u"зрение",
        u"зритель",
        u"зубной",
        u"зыбкий",
        u"зять",
        u"игла",
        u"иголка",
        u"играть",
        u"идея",
        u"идиот",
        u"идол",
        u"идти",
        u"иерархия",
        u"избрать",
        u"известие",
        u"изгонять",
        u"издание",
        u"излагать",
        u"изменять",
        u"износ",
        u"изоляция",
        u"изрядный",
        u"изучать",
        u"изымать",
        u"изящный",
        u"икона",
        u"икра",
        u"иллюзия",
        u"имбирь",
        u"иметь",
        u"имидж",
        u"иммунный",
        u"империя",
        u"инвестор",
        u"индивид",
        u"инерция",
        u"инженер",
        u"иномарка",
        u"институт",
        u"интерес",
        u"инфекция",
        u"инцидент",
        u"ипподром",
        u"ирис",
        u"ирония",
        u"искать",
        u"история",
        u"исходить",
        u"исчезать",
        u"итог",
        u"июль",
        u"июнь",
        u"кабинет",
        u"кавалер",
        u"кадр",
        u"казарма",
        u"кайф",
        u"кактус",
        u"калитка",
        u"камень",
        u"канал",
        u"капитан",
        u"картина",
        u"касса",
        u"катер",
        u"кафе",
        u"качество",
        u"каша",
        u"каюта",
        u"квартира",
        u"квинтет",
        u"квота",
        u"кедр",
        u"кекс",
        u"кенгуру",
        u"кепка",
        u"керосин",
        u"кетчуп",
        u"кефир",
        u"кибитка",
        u"кивнуть",
        u"кидать",
        u"километр",
        u"кино",
        u"киоск",
        u"кипеть",
        u"кирпич",
        u"кисть",
        u"китаец",
        u"класс",
        u"клетка",
        u"клиент",
        u"клоун",
        u"клуб",
        u"клык",
        u"ключ",
        u"клятва",
        u"книга",
        u"кнопка",
        u"кнут",
        u"князь",
        u"кобура",
        u"ковер",
        u"коготь",
        u"кодекс",
        u"кожа",
        u"козел",
        u"койка",
        u"коктейль",
        u"колено",
        u"компания",
        u"конец",
        u"копейка",
        u"короткий",
        u"костюм",
        u"котел",
        u"кофе",
        u"кошка",
        u"красный",
        u"кресло",
        u"кричать",
        u"кровь",
        u"крупный",
        u"крыша",
        u"крючок",
        u"кубок",
        u"кувшин",
        u"кудрявый",
        u"кузов",
        u"кукла",
        u"культура",
        u"кумир",
        u"купить",
        u"курс",
        u"кусок",
        u"кухня",
        u"куча",
        u"кушать",
        u"кювет",
        u"лабиринт",
        u"лавка",
        u"лагерь",
        u"ладонь",
        u"лазерный",
        u"лайнер",
        u"лакей",
        u"лампа",
        u"ландшафт",
        u"лапа",
        u"ларек",
        u"ласковый",
        u"лауреат",
        u"лачуга",
        u"лаять",
        u"лгать",
        u"лебедь",
        u"левый",
        u"легкий",
        u"ледяной",
        u"лежать",
        u"лекция",
        u"лента",
        u"лепесток",
        u"лесной",
        u"лето",
        u"лечь",
        u"леший",
        u"лживый",
        u"либерал",
        u"ливень",
        u"лига",
        u"лидер",
        u"ликовать",
        u"лиловый",
        u"лимон",
        u"линия",
        u"липа",
        u"лирика",
        u"лист",
        u"литр",
        u"лифт",
        u"лихой",
        u"лицо",
        u"личный",
        u"лишний",
        u"лобовой",
        u"ловить",
        u"логика",
        u"лодка",
        u"ложка",
        u"лозунг",
        u"локоть",
        u"ломать",
        u"лоно",
        u"лопата",
        u"лорд",
        u"лось",
        u"лоток",
        u"лохматый",
        u"лошадь",
        u"лужа",
        u"лукавый",
        u"луна",
        u"лупить",
        u"лучший",
        u"лыжный",
        u"лысый",
        u"львиный",
        u"льгота",
        u"льдина",
        u"любить",
        u"людской",
        u"люстра",
        u"лютый",
        u"лягушка",
        u"магазин",
        u"мадам",
        u"мазать",
        u"майор",
        u"максимум",
        u"мальчик",
        u"манера",
        u"март",
        u"масса",
        u"мать",
        u"мафия",
        u"махать",
        u"мачта",
        u"машина",
        u"маэстро",
        u"маяк",
        u"мгла",
        u"мебель",
        u"медведь",
        u"мелкий",
        u"мемуары",
        u"менять",
        u"мера",
        u"место",
        u"метод",
        u"механизм",
        u"мечтать",
        u"мешать",
        u"миграция",
        u"мизинец",
        u"микрофон",
        u"миллион",
        u"минута",
        u"мировой",
        u"миссия",
        u"митинг",
        u"мишень",
        u"младший",
        u"мнение",
        u"мнимый",
        u"могила",
        u"модель",
        u"мозг",
        u"мойка",
        u"мокрый",
        u"молодой",
        u"момент",
        u"монах",
        u"море",
        u"мост",
        u"мотор",
        u"мохнатый",
        u"мочь",
        u"мошенник",
        u"мощный",
        u"мрачный",
        u"мстить",
        u"мудрый",
        u"мужчина",
        u"музыка",
        u"мука",
        u"мумия",
        u"мундир",
        u"муравей",
        u"мусор",
        u"мутный",
        u"муфта",
        u"муха",
        u"мучить",
        u"мушкетер",
        u"мыло",
        u"мысль",
        u"мыть",
        u"мычать",
        u"мышь",
        u"мэтр",
        u"мюзикл",
        u"мягкий",
        u"мякиш",
        u"мясо",
        u"мятый",
        u"мячик",
        u"набор",
        u"навык",
        u"нагрузка",
        u"надежда",
        u"наемный",
        u"нажать",
        u"называть",
        u"наивный",
        u"накрыть",
        u"налог",
        u"намерен",
        u"наносить",
        u"написать",
        u"народ",
        u"натура",
        u"наука",
        u"нация",
        u"начать",
        u"небо",
        u"невеста",
        u"негодяй",
        u"неделя",
        u"нежный",
        u"незнание",
        u"нелепый",
        u"немалый",
        u"неправда",
        u"нервный",
        u"нести",
        u"нефть",
        u"нехватка",
        u"нечистый",
        u"неясный",
        u"нива",
        u"нижний",
        u"низкий",
        u"никель",
        u"нирвана",
        u"нить",
        u"ничья",
        u"ниша",
        u"нищий",
        u"новый",
        u"нога",
        u"ножницы",
        u"ноздря",
        u"ноль",
        u"номер",
        u"норма",
        u"нота",
        u"ночь",
        u"ноша",
        u"ноябрь",
        u"нрав",
        u"нужный",
        u"нутро",
        u"нынешний",
        u"нырнуть",
        u"ныть",
        u"нюанс",
        u"нюхать",
        u"няня",
        u"оазис",
        u"обаяние",
        u"обвинять",
        u"обгонять",
        u"обещать",
        u"обжигать",
        u"обзор",
        u"обида",
        u"область",
        u"обмен",
        u"обнимать",
        u"оборона",
        u"образ",
        u"обучение",
        u"обходить",
        u"обширный",
        u"общий",
        u"объект",
        u"обычный",
        u"обязать",
        u"овальный",
        u"овес",
        u"овощи",
        u"овраг",
        u"овца",
        u"овчарка",
        u"огненный",
        u"огонь",
        u"огромный",
        u"огурец",
        u"одежда",
        u"одинокий",
        u"одобрить",
        u"ожидать",
        u"ожог",
        u"озарение",
        u"озеро",
        u"означать",
        u"оказать",
        u"океан",
        u"оклад",
        u"окно",
        u"округ",
        u"октябрь",
        u"окурок",
        u"олень",
        u"опасный",
        u"операция",
        u"описать",
        u"оплата",
        u"опора",
        u"оппонент",
        u"опрос",
        u"оптимизм",
        u"опускать",
        u"опыт",
        u"орать",
        u"орбита",
        u"орган",
        u"орден",
        u"орел",
        u"оригинал",
        u"оркестр",
        u"орнамент",
        u"оружие",
        u"осадок",
        u"освещать",
        u"осень",
        u"осина",
        u"осколок",
        u"осмотр",
        u"основной",
        u"особый",
        u"осуждать",
        u"отбор",
        u"отвечать",
        u"отдать",
        u"отец",
        u"отзыв",
        u"открытие",
        u"отмечать",
        u"относить",
        u"отпуск",
        u"отрасль",
        u"отставка",
        u"оттенок",
        u"отходить",
        u"отчет",
        u"отъезд",
        u"офицер",
        u"охапка",
        u"охота",
        u"охрана",
        u"оценка",
        u"очаг",
        u"очередь",
        u"очищать",
        u"очки",
        u"ошейник",
        u"ошибка",
        u"ощущение",
        u"павильон",
        u"падать",
        u"паек",
        u"пакет",
        u"палец",
        u"память",
        u"панель",
        u"папка",
        u"партия",
        u"паспорт",
        u"патрон",
        u"пауза",
        u"пафос",
        u"пахнуть",
        u"пациент",
        u"пачка",
        u"пашня",
        u"певец",
        u"педагог",
        u"пейзаж",
        u"пельмень",
        u"пенсия",
        u"пепел",
        u"период",
        u"песня",
        u"петля",
        u"пехота",
        u"печать",
        u"пешеход",
        u"пещера",
        u"пианист",
        u"пиво",
        u"пиджак",
        u"пиковый",
        u"пилот",
        u"пионер",
        u"пирог",
        u"писать",
        u"пить",
        u"пицца",
        u"пишущий",
        u"пища",
        u"план",
        u"плечо",
        u"плита",
        u"плохой",
        u"плыть",
        u"плюс",
        u"пляж",
        u"победа",
        u"повод",
        u"погода",
        u"подумать",
        u"поехать",
        u"пожимать",
        u"позиция",
        u"поиск",
        u"покой",
        u"получать",
        u"помнить",
        u"пони",
        u"поощрять",
        u"попадать",
        u"порядок",
        u"пост",
        u"поток",
        u"похожий",
        u"поцелуй",
        u"почва",
        u"пощечина",
        u"поэт",
        u"пояснить",
        u"право",
        u"предмет",
        u"проблема",
        u"пруд",
        u"прыгать",
        u"прямой",
        u"психолог",
        u"птица",
        u"публика",
        u"пугать",
        u"пудра",
        u"пузырь",
        u"пуля",
        u"пункт",
        u"пурга",
        u"пустой",
        u"путь",
        u"пухлый",
        u"пучок",
        u"пушистый",
        u"пчела",
        u"пшеница",
        u"пыль",
        u"пытка",
        u"пыхтеть",
        u"пышный",
        u"пьеса",
        u"пьяный",
        u"пятно",
        u"работа",
        u"равный",
        u"радость",
        u"развитие",
        u"район",
        u"ракета",
        u"рамка",
        u"ранний",
        u"рапорт",
        u"рассказ",
        u"раунд",
        u"рация",
        u"рвать",
        u"реальный",
        u"ребенок",
        u"реветь",
        u"регион",
        u"редакция",
        u"реестр",
        u"режим",
        u"резкий",
        u"рейтинг",
        u"река",
        u"религия",
        u"ремонт",
        u"рента",
        u"реплика",
        u"ресурс",
        u"реформа",
        u"рецепт",
        u"речь",
        u"решение",
        u"ржавый",
        u"рисунок",
        u"ритм",
        u"рифма",
        u"робкий",
        u"ровный",
        u"рогатый",
        u"родитель",
        u"рождение",
        u"розовый",
        u"роковой",
        u"роль",
        u"роман",
        u"ронять",
        u"рост",
        u"рота",
        u"роща",
        u"рояль",
        u"рубль",
        u"ругать",
        u"руда",
        u"ружье",
        u"руины",
        u"рука",
        u"руль",
        u"румяный",
        u"русский",
        u"ручка",
        u"рыба",
        u"рывок",
        u"рыдать",
        u"рыжий",
        u"рынок",
        u"рысь",
        u"рыть",
        u"рыхлый",
        u"рыцарь",
        u"рычаг",
        u"рюкзак",
        u"рюмка",
        u"рябой",
        u"рядовой",
        u"сабля",
        u"садовый",
        u"сажать",
        u"салон",
        u"самолет",
        u"сани",
        u"сапог",
        u"сарай",
        u"сатира",
        u"сауна",
        u"сахар",
        u"сбегать",
        u"сбивать",
        u"сбор",
        u"сбыт",
        u"свадьба",
        u"свет",
        u"свидание",
        u"свобода",
        u"связь",
        u"сгорать",
        u"сдвигать",
        u"сеанс",
        u"северный",
        u"сегмент",
        u"седой",
        u"сезон",
        u"сейф",
        u"секунда",
        u"сельский",
        u"семья",
        u"сентябрь",
        u"сердце",
        u"сеть",
        u"сечение",
        u"сеять",
        u"сигнал",
        u"сидеть",
        u"сизый",
        u"сила",
        u"символ",
        u"синий",
        u"сирота",
        u"система",
        u"ситуация",
        u"сиять",
        u"сказать",
        u"скважина",
        u"скелет",
        u"скидка",
        u"склад",
        u"скорый",
        u"скрывать",
        u"скучный",
        u"слава",
        u"слеза",
        u"слияние",
        u"слово",
        u"случай",
        u"слышать",
        u"слюна",
        u"смех",
        u"смирение",
        u"смотреть",
        u"смутный",
        u"смысл",
        u"смятение",
        u"снаряд",
        u"снег",
        u"снижение",
        u"сносить",
        u"снять",
        u"событие",
        u"совет",
        u"согласие",
        u"сожалеть",
        u"сойти",
        u"сокол",
        u"солнце",
        u"сомнение",
        u"сонный",
        u"сообщать",
        u"соперник",
        u"сорт",
        u"состав",
        u"сотня",
        u"соус",
        u"социолог",
        u"сочинять",
        u"союз",
        u"спать",
        u"спешить",
        u"спина",
        u"сплошной",
        u"способ",
        u"спутник",
        u"средство",
        u"срок",
        u"срывать",
        u"стать",
        u"ствол",
        u"стена",
        u"стихи",
        u"сторона",
        u"страна",
        u"студент",
        u"стыд",
        u"субъект",
        u"сувенир",
        u"сугроб",
        u"судьба",
        u"суета",
        u"суждение",
        u"сукно",
        u"сулить",
        u"сумма",
        u"сунуть",
        u"супруг",
        u"суровый",
        u"сустав",
        u"суть",
        u"сухой",
        u"суша",
        u"существо",
        u"сфера",
        u"схема",
        u"сцена",
        u"счастье",
        u"счет",
        u"считать",
        u"сшивать",
        u"съезд",
        u"сынок",
        u"сыпать",
        u"сырье",
        u"сытый",
        u"сыщик",
        u"сюжет",
        u"сюрприз",
        u"таблица",
        u"таежный",
        u"таинство",
        u"тайна",
        u"такси",
        u"талант",
        u"таможня",
        u"танец",
        u"тарелка",
        u"таскать",
        u"тахта",
        u"тачка",
        u"таять",
        u"тварь",
        u"твердый",
        u"творить",
        u"театр",
        u"тезис",
        u"текст",
        u"тело",
        u"тема",
        u"тень",
        u"теория",
        u"теплый",
        u"терять",
        u"тесный",
        u"тетя",
        u"техника",
        u"течение",
        u"тигр",
        u"типичный",
        u"тираж",
        u"титул",
        u"тихий",
        u"тишина",
        u"ткань",
        u"товарищ",
        u"толпа",
        u"тонкий",
        u"топливо",
        u"торговля",
        u"тоска",
        u"точка",
        u"тощий",
        u"традиция",
        u"тревога",
        u"трибуна",
        u"трогать",
        u"труд",
        u"трюк",
        u"тряпка",
        u"туалет",
        u"тугой",
        u"туловище",
        u"туман",
        u"тундра",
        u"тупой",
        u"турнир",
        u"тусклый",
        u"туфля",
        u"туча",
        u"туша",
        u"тыкать",
        u"тысяча",
        u"тьма",
        u"тюльпан",
        u"тюрьма",
        u"тяга",
        u"тяжелый",
        u"тянуть",
        u"убеждать",
        u"убирать",
        u"убогий",
        u"убыток",
        u"уважение",
        u"уверять",
        u"увлекать",
        u"угнать",
        u"угол",
        u"угроза",
        u"удар",
        u"удивлять",
        u"удобный",
        u"уезд",
        u"ужас",
        u"ужин",
        u"узел",
        u"узкий",
        u"узнавать",
        u"узор",
        u"уйма",
        u"уклон",
        u"укол",
        u"уксус",
        u"улетать",
        u"улица",
        u"улучшать",
        u"улыбка",
        u"уметь",
        u"умиление",
        u"умный",
        u"умолять",
        u"умысел",
        u"унижать",
        u"уносить",
        u"уныние",
        u"упасть",
        u"уплата",
        u"упор",
        u"упрекать",
        u"упускать",
        u"уран",
        u"урна",
        u"уровень",
        u"усадьба",
        u"усердие",
        u"усилие",
        u"ускорять",
        u"условие",
        u"усмешка",
        u"уснуть",
        u"успеть",
        u"усыпать",
        u"утешать",
        u"утка",
        u"уточнять",
        u"утро",
        u"утюг",
        u"уходить",
        u"уцелеть",
        u"участие",
        u"ученый",
        u"учитель",
        u"ушко",
        u"ущерб",
        u"уютный",
        u"уяснять",
        u"фабрика",
        u"фаворит",
        u"фаза",
        u"файл",
        u"факт",
        u"фамилия",
        u"фантазия",
        u"фара",
        u"фасад",
        u"февраль",
        u"фельдшер",
        u"феномен",
        u"ферма",
        u"фигура",
        u"физика",
        u"фильм",
        u"финал",
        u"фирма",
        u"фишка",
        u"флаг",
        u"флейта",
        u"флот",
        u"фокус",
        u"фольклор",
        u"фонд",
        u"форма",
        u"фото",
        u"фраза",
        u"фреска",
        u"фронт",
        u"фрукт",
        u"функция",
        u"фуражка",
        u"футбол",
        u"фыркать",
        u"халат",
        u"хамство",
        u"хаос",
        u"характер",
        u"хата",
        u"хватать",
        u"хвост",
        u"хижина",
        u"хилый",
        u"химия",
        u"хирург",
        u"хитрый",
        u"хищник",
        u"хлам",
        u"хлеб",
        u"хлопать",
        u"хмурый",
        u"ходить",
        u"хозяин",
        u"хоккей",
        u"холодный",
        u"хороший",
        u"хотеть",
        u"хохотать",
        u"храм",
        u"хрен",
        u"хриплый",
        u"хроника",
        u"хрупкий",
        u"художник",
        u"хулиган",
        u"хутор",
        u"царь",
        u"цвет",
        u"цель",
        u"цемент",
        u"центр",
        u"цепь",
        u"церковь",
        u"цикл",
        u"цилиндр",
        u"циничный",
        u"цирк",
        u"цистерна",
        u"цитата",
        u"цифра",
        u"цыпленок",
        u"чадо",
        u"чайник",
        u"часть",
        u"чашка",
        u"человек",
        u"чемодан",
        u"чепуха",
        u"черный",
        u"честь",
        u"четкий",
        u"чехол",
        u"чиновник",
        u"число",
        u"читать",
        u"членство",
        u"чреватый",
        u"чтение",
        u"чувство",
        u"чугунный",
        u"чудо",
        u"чужой",
        u"чукча",
        u"чулок",
        u"чума",
        u"чуткий",
        u"чучело",
        u"чушь",
        u"шаблон",
        u"шагать",
        u"шайка",
        u"шакал",
        u"шалаш",
        u"шампунь",
        u"шанс",
        u"шапка",
        u"шарик",
        u"шасси",
        u"шатер",
        u"шахта",
        u"шашлык",
        u"швейный",
        u"швырять",
        u"шевелить",
        u"шедевр",
        u"шейка",
        u"шелковый",
        u"шептать",
        u"шерсть",
        u"шестерка",
        u"шикарный",
        u"шинель",
        u"шипеть",
        u"широкий",
        u"шить",
        u"шишка",
        u"шкаф",
        u"школа",
        u"шкура",
        u"шланг",
        u"шлем",
        u"шлюпка",
        u"шляпа",
        u"шнур",
        u"шоколад",
        u"шорох",
        u"шоссе",
        u"шофер",
        u"шпага",
        u"шпион",
        u"шприц",
        u"шрам",
        u"шрифт",
        u"штаб",
        u"штора",
        u"штраф",
        u"штука",
        u"штык",
        u"шуба",
        u"шуметь",
        u"шуршать",
        u"шутка",
        u"щадить",
        u"щедрый",
        u"щека",
        u"щель",
        u"щенок",
        u"щепка",
        u"щетка",
        u"щука",
        u"эволюция",
        u"эгоизм",
        u"экзамен",
        u"экипаж",
        u"экономия",
        u"экран",
        u"эксперт",
        u"элемент",
        u"элита",
        u"эмблема",
        u"эмигрант",
        u"эмоция",
        u"энергия",
        u"эпизод",
        u"эпоха",
        u"эскиз",
        u"эссе",
        u"эстрада",
        u"этап",
        u"этика",
        u"этюд",
        u"эфир",
        u"эффект",
        u"эшелон",
        u"юбилей",
        u"юбка",
        u"южный",
        u"юмор",
        u"юноша",
        u"юрист",
        u"яблоко",
        u"явление",
        u"ягода",
        u"ядерный",
        u"ядовитый",
        u"ядро",
        u"язва",
        u"язык",
        u"яйцо",
        u"якорь",
        u"январь",
        u"японец",
        u"яркий",
        u"ярмарка",
        u"ярость",
        u"ярус",
        u"ясный",
        u"яхта",
        u"ячейка",
        u"ящик"
    ]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Word list originally created by dabura667 and released under The MIT License (MIT)
#
# The MIT License (MIT)
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
# Code surrounding the word list is Copyright (c) 2014-2018, The Monero Project
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice, this list of
#    conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice, this list
#    of conditions and the following disclaimer in the documentation and/or other
#    materials provided with the distribution.
#
# 3. Neither the name of the copyright holder nor the names of its contributors may be
#    used to endorse or promote products derived from this software without specific
#    prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
# THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
# STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
# THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
# list of words from:
#     https://github.com/monero-project/monero/blob/master/src/mnemonics/japanese.h
#     Most recent commit: 8ea3c4d54429976e9001b8cc4868b721e6747e3c


from .wordlist import Wordlist


class Japanese(Wordlist):
    language_name = u"日本語"
    english_language_name = "Japanese"
    unique_prefix_length = 4
    word_list = [
        u"あいこくしん",
        u"あいさつ",
        u"あいだ",
        u"あおぞら",
        u"あかちゃん",
        u"あきる",
        u"あけがた",
        u"あける",
        u"あこがれる",
        u"あさい",
        u"あさひ",
        u"あしあと",
        u"あじわう",
        u"あずかる",
        u"あずき",
        u"あそぶ",
        u"あたえる",
        u"あたためる",
        u"あたりまえ",
        u"あたる",
        u"あつい",
        u"あつかう",
        u"あっしゅく",
        u"あつまり",
        u"あつめる",
        u"あてな",
        u"あてはまる",
        u"あひる",
        u"あぶら",
        u"あぶる",
        u"あふれる",
        u"あまい",
        u"あまど",
        u"あまやかす",
        u"あまり",
        u"あみもの",
        u"あめりか",
        u"あやまる",
        u"あゆむ",
        u"あらいぐま",
        u"あらし",
        u"あらすじ",
        u"あらためる",
        u"あらゆる",
        u"あらわす",
        u"ありがとう",
        u"あわせる",
        u"あわてる",
        u"あんい",
        u"あんがい",
        u"あんこ",
        u"あんぜん",
        u"あんてい",
        u"あんない",
        u"あんまり",
        u"いいだす",
        u"いおん",
        u"いがい",
        u"いがく",
        u"いきおい",
        u"いきなり",
        u"いきもの",
        u"いきる",
        u"いくじ",
        u"いくぶん",
        u"いけばな",
        u"いけん",
        u"いこう",
        u"いこく",
        u"いこつ",
        u"いさましい",
        u"いさん",
        u"いしき",
        u"いじゅう",
        u"いじょう",
        u"いじわる",
        u"いずみ",
        u"いずれ",
        u"いせい",
        u"いせえび",
        u"いせかい",
        u"いせき",
        u"いぜん",
        u"いそうろう",
        u"いそがしい",
        u"いだい",
        u"いだく",
        u"いたずら",
        u"いたみ",
        u"いたりあ",
        u"いちおう",
        u"いちじ",
        u"いちど",
        u"いちば",
        u"いちぶ",
        u"いちりゅう",
        u"いつか",
        u"いっしゅん",
        u"いっせい",
        u"いっそう",
        u"いったん",
        u"いっち",
        u"いってい",
        u"いっぽう",
        u"いてざ",
        u"いてん",
        u"いどう",
        u"いとこ",
        u"いない",
        u"いなか",
        u"いねむり",
        u"いのち",
        u"いのる",
        u"いはつ",
        u"いばる",
        u"いはん",
        u"いびき",
        u"いひん",
        u"いふく",
        u"いへん",
        u"いほう",
        u"いみん",
        u"いもうと",
        u"いもたれ",
        u"いもり",
        u"いやがる",
        u"いやす",
        u"いよかん",
        u"いよく",
        u"いらい",
        u"いらすと",
        u"いりぐち",
        u"いりょう",
        u"いれい",
        u"いれもの",
        u"いれる",
        u"いろえんぴつ",
        u"いわい",
        u"いわう",
        u"いわかん",
        u"いわば",
        u"いわゆる",
        u"いんげんまめ",
        u"いんさつ",
        u"いんしょう",
        u"いんよう",
        u"うえき",
        u"うえる",
        u"うおざ",
        u"うがい",
        u"うかぶ",
        u"うかべる",
        u"うきわ",
        u"うくらいな",
        u"うくれれ",
        u"うけたまわる",
        u"うけつけ",
        u"うけとる",
        u"うけもつ",
        u"うける",
        u"うごかす",
        u"うごく",
        u"うこん",
        u"うさぎ",
        u"うしなう",
        u"うしろがみ",
        u"うすい",
        u"うすぎ",
        u"うすぐらい",
        u"うすめる",
        u"うせつ",
        u"うちあわせ",
        u"うちがわ",
        u"うちき",
        u"うちゅう",
        u"うっかり",
        u"うつくしい",
        u"うったえる",
        u"うつる",
        u"うどん",
        u"うなぎ",
        u"うなじ",
        u"うなずく",
        u"うなる",
        u"うねる",
        u"うのう",
        u"うぶげ",
        u"うぶごえ",
        u"うまれる",
        u"うめる",
        u"うもう",
        u"うやまう",
        u"うよく",
        u"うらがえす",
        u"うらぐち",
        u"うらない",
        u"うりあげ",
        u"うりきれ",
        u"うるさい",
        u"うれしい",
        u"うれゆき",
        u"うれる",
        u"うろこ",
        u"うわき",
        u"うわさ",
        u"うんこう",
        u"うんちん",
        u"うんてん",
        u"うんどう",
        u"えいえん",
        u"えいが",
        u"えいきょう",
        u"えいご",
        u"えいせい",
        u"えいぶん",
        u"えいよう",
        u"えいわ",
        u"えおり",
        u"えがお",
        u"えがく",
        u"えきたい",
        u"えくせる",
        u"えしゃく",
        u"えすて",
        u"えつらん",
        u"えのぐ",
        u"えほうまき",
        u"えほん",
        u"えまき",
        u"えもじ",
        u"えもの",
        u"えらい",
        u"えらぶ",
        u"えりあ",
        u"えんえん",
        u"えんかい",
        u"えんぎ",
        u"えんげき",
        u"えんしゅう",
        u"えんぜつ",
        u"えんそく",
        u"えんちょう",
        u"えんとつ",
        u"おいかける",
        u"おいこす",
        u"おいしい",
        u"おいつく",
        u"おうえん",
        u"おうさま",
        u"おうじ",
        u"おうせつ",
        u"おうたい",
        u"おうふく",
        u"おうべい",
        u"おうよう",
        u"おえる",
        u"おおい",
        u"おおう",
        u"おおどおり",
        u"おおや",
        u"おおよそ",
        u"おかえり",
        u"おかず",
        u"おがむ",
        u"おかわり",
        u"おぎなう",
        u"おきる",
        u"おくさま",
        u"おくじょう",
        u"おくりがな",
        u"おくる",
        u"おくれる",
        u"おこす",
        u"おこなう",
        u"おこる",
        u"おさえる",
        u"おさない",
        u"おさめる",
        u"おしいれ",
        u"おしえる",
        u"おじぎ",
        u"おじさん",
        u"おしゃれ",
        u"おそらく",
        u"おそわる",
        u"おたがい",
        u"おたく",
        u"おだやか",
        u"おちつく",
        u"おっと",
        u"おつり",
        u"おでかけ",
        u"おとしもの",
        u"おとなしい",
        u"おどり",
        u"おどろかす",
        u"おばさん",
        u"おまいり",
        u"おめでとう",
        u"おもいで",
        u"おもう",
        u"おもたい",
        u"おもちゃ",
        u"おやつ",
        u"おやゆび",
        u"およぼす",
        u"おらんだ",
        u"おろす",
        u"おんがく",
        u"おんけい",
        u"おんしゃ",
        u"おんせん",
        u"おんだん",
        u"おんちゅう",
        u"おんどけい",
        u"かあつ",
        u"かいが",
        u"がいき",
        u"がいけん",
        u"がいこう",
        u"かいさつ",
        u"かいしゃ",
        u"かいすいよく",
        u"かいぜん",
        u"かいぞうど",
        u"かいつう",
        u"かいてん",
        u"かいとう",
        u"かいふく",
        u"がいへき",
        u"かいほう",
        u"かいよう",
        u"がいらい",
        u"かいわ",
        u"かえる",
        u"かおり",
        u"かかえる",
        u"かがく",
        u"かがし",
        u"かがみ",
        u"かくご",
        u"かくとく",
        u"かざる",
        u"がぞう",
        u"かたい",
        u"かたち",
        u"がちょう",
        u"がっきゅう",
        u"がっこう",
        u"がっさん",
        u"がっしょう",
        u"かなざわし",
        u"かのう",
        u"がはく",
        u"かぶか",
        u"かほう",
        u"かほご",
        u"かまう",
        u"かまぼこ",
        u"かめれおん",
        u"かゆい",
        u"かようび",
        u"からい",
        u"かるい",
        u"かろう",
        u"かわく",
        u"かわら",
        u"がんか",
        u"かんけい",
        u"かんこう",
        u"かんしゃ",
        u"かんそう",
        u"かんたん",
        u"かんち",
        u"がんばる",
        u"きあい",
        u"きあつ",
        u"きいろ",
        u"ぎいん",
        u"きうい",
        u"きうん",
        u"きえる",
        u"きおう",
        u"きおく",
        u"きおち",
        u"きおん",
        u"きかい",
        u"きかく",
        u"きかんしゃ",
        u"ききて",
        u"きくばり",
        u"きくらげ",
        u"きけんせい",
        u"きこう",
        u"きこえる",
        u"きこく",
        u"きさい",
        u"きさく",
        u"きさま",
        u"きさらぎ",
        u"ぎじかがく",
        u"ぎしき",
        u"ぎじたいけん",
        u"ぎじにってい",
        u"ぎじゅつしゃ",
        u"きすう",
        u"きせい",
        u"きせき",
        u"きせつ",
        u"きそう",
        u"きぞく",
        u"きぞん",
        u"きたえる",
        u"きちょう",
        u"きつえん",
        u"ぎっちり",
        u"きつつき",
        u"きつね",
        u"きてい",
        u"きどう",
        u"きどく",
        u"きない",
        u"きなが",
        u"きなこ",
        u"きぬごし",
        u"きねん",
        u"きのう",
        u"きのした",
        u"きはく",
        u"きびしい",
        u"きひん",
        u"きふく",
        u"きぶん",
        u"きぼう",
        u"きほん",
        u"きまる",
        u"きみつ",
        u"きむずかしい",
        u"きめる",
        u"きもだめし",
        u"きもち",
        u"きもの",
        u"きゃく",
        u"きやく",
        u"ぎゅうにく",
        u"きよう",
        u"きょうりゅう",
        u"きらい",
        u"きらく",
        u"きりん",
        u"きれい",
        u"きれつ",
        u"きろく",
        u"ぎろん",
        u"きわめる",
        u"ぎんいろ",
        u"きんかくじ",
        u"きんじょ",
        u"きんようび",
        u"ぐあい",
        u"くいず",
        u"くうかん",
        u"くうき",
        u"くうぐん",
        u"くうこう",
        u"ぐうせい",
        u"くうそう",
        u"ぐうたら",
        u"くうふく",
        u"くうぼ",
        u"くかん",
        u"くきょう",
        u"くげん",
        u"ぐこう",
        u"くさい",
        u"くさき",
        u"くさばな",
        u"くさる",
        u"くしゃみ",
        u"くしょう",
        u"くすのき",
        u"くすりゆび",
        u"くせげ",
        u"くせん",
        u"ぐたいてき",
        u"くださる",
        u"くたびれる",
        u"くちこみ",
        u"くちさき",
        u"くつした",
        u"ぐっすり",
        u"くつろぐ",
        u"くとうてん",
        u"くどく",
        u"くなん",
        u"くねくね",
        u"くのう",
        u"くふう",
        u"くみあわせ",
        u"くみたてる",
        u"くめる",
        u"くやくしょ",
        u"くらす",
        u"くらべる",
        u"くるま",
        u"くれる",
        u"くろう",
        u"くわしい",
        u"ぐんかん",
        u"ぐんしょく",
        u"ぐんたい",
        u"ぐんて",
        u"けあな",
        u"けいかく",
        u"けいけん",
        u"けいこ",
        u"けいさつ",
        u"げいじゅつ",
        u"けいたい",
        u"げいのうじん",
        u"けいれき",
        u"けいろ",
        u"けおとす",
        u"けおりもの",
        u"げきか",
        u"げきげん",
        u"げきだん",
        u"げきちん",
        u"げきとつ",
        u"げきは",
        u"げきやく",
        u"げこう",
        u"げこくじょう",
        u"げざい",
        u"けさき",
        u"げざん",
        u"けしき",
        u"けしごむ",
        u"けしょう",
        u"げすと",
        u"けたば",
        u"けちゃっぷ",
        u"けちらす",
        u"けつあつ",
        u"けつい",
        u"けつえき",
        u"けっこん",
        u"けつじょ",
        u"けっせき",
        u"けってい",
        u"けつまつ",
        u"げつようび",
        u"げつれい",
        u"けつろん",
        u"げどく",
        u"けとばす",
        u"けとる",
        u"けなげ",
        u"けなす",
        u"けなみ",
        u"けぬき",
        u"げねつ",
        u"けねん",
        u"けはい",
        u"げひん",
        u"けぶかい",
        u"げぼく",
        u"けまり",
        u"けみかる",
        u"けむし",
        u"けむり",
        u"けもの",
        u"けらい",
        u"けろけろ",
        u"けわしい",
        u"けんい",
        u"けんえつ",
        u"けんお",
        u"けんか",
        u"げんき",
        u"けんげん",
        u"けんこう",
        u"けんさく",
        u"けんしゅう",
        u"けんすう",
        u"げんそう",
        u"けんちく",
        u"けんてい",
        u"けんとう",
        u"けんない",
        u"けんにん",
        u"げんぶつ",
        u"けんま",
        u"けんみん",
        u"けんめい",
        u"けんらん",
        u"けんり",
        u"こあくま",
        u"こいぬ",
        u"こいびと",
        u"ごうい",
        u"こうえん",
        u"こうおん",
        u"こうかん",
        u"ごうきゅう",
        u"ごうけい",
        u"こうこう",
        u"こうさい",
        u"こうじ",
        u"こうすい",
        u"ごうせい",
        u"こうそく",
        u"こうたい",
        u"こうちゃ",
        u"こうつう",
        u"こうてい",
        u"こうどう",
        u"こうない",
        u"こうはい",
        u"ごうほう",
        u"ごうまん",
        u"こうもく",
        u"こうりつ",
        u"こえる",
        u"こおり",
        u"ごかい",
        u"ごがつ",
        u"ごかん",
        u"こくご",
        u"こくさい",
        u"こくとう",
        u"こくない",
        u"こくはく",
        u"こぐま",
        u"こけい",
        u"こける",
        u"ここのか",
        u"こころ",
        u"こさめ",
        u"こしつ",
        u"こすう",
        u"こせい",
        u"こせき",
        u"こぜん",
        u"こそだて",
        u"こたい",
        u"こたえる",
        u"こたつ",
        u"こちょう",
        u"こっか",
        u"こつこつ",
        u"こつばん",
        u"こつぶ",
        u"こてい",
        u"こてん",
        u"ことがら",
        u"ことし",
        u"ことば",
        u"ことり",
        u"こなごな",
        u"こねこね",
        u"このまま",
        u"このみ",
        u"このよ",
        u"ごはん",
        u"こひつじ",
        u"こふう",
        u"こふん",
        u"こぼれる",
        u"ごまあぶら",
        u"こまかい",
        u"ごますり",
        u"こまつな",
        u"こまる",
        u"こむぎこ",
        u"こもじ",
        u"こもち",
        u"こもの",
        u"こもん",
        u"こやく",
        u"こやま",
        u"こゆう",
        u"こゆび",
        u"こよい",
        u"こよう",
        u"こりる",
        u"これくしょん",
        u"ころっけ",
        u"こわもて",
        u"こわれる",
        u"こんいん",
        u"こんかい",
        u"こんき",
        u"こんしゅう",
        u"こんすい",
        u"こんだて",
        u"こんとん",
        u"こんなん",
        u"こんびに",
        u"こんぽん",
        u"こんまけ",
        u"こんや",
        u"こんれい",
        u"こんわく",
        u"ざいえき",
        u"さいかい",
        u"さいきん",
        u"ざいげん",
        u"ざいこ",
        u"さいしょ",
        u"さいせい",
        u"ざいたく",
        u"ざいちゅう",
        u"さいてき",
        u"ざいりょう",
        u"さうな",
        u"さかいし",
        u"さがす",
        u"さかな",
        u"さかみち",
        u"さがる",
        u"さぎょう",
        u"さくし",
        u"さくひん",
        u"さくら",
        u"さこく",
        u"さこつ",
        u"さずかる",
        u"ざせき",
        u"さたん",
        u"さつえい",
        u"ざつおん",
        u"ざっか",
        u"ざつがく",
        u"さっきょく",
        u"ざっし",
        u"さつじん",
        u"ざっそう",
        u"さつたば",
        u"さつまいも",
        u"さてい",
        u"さといも",
        u"さとう",
        u"さとおや",
        u"さとし",
        u"さとる",
        u"さのう",
        u"さばく",
        u"さびしい",
        u"さべつ",
        u"さほう",
        u"さほど",
        u"さます",
        u"さみしい",
        u"さみだれ",
        u"さむけ",
        u"さめる",
        u"さやえんどう",
        u"さゆう",
        u"さよう",
        u"さよく",
        u"さらだ",
        u"ざるそば",
        u"さわやか",
        u"さわる",
        u"さんいん",
        u"さんか",
        u"さんきゃく",
        u"さんこう",
        u"さんさい",
        u"ざんしょ",
        u"さんすう",
        u"さんせい",
        u"さんそ",
        u"さんち",
        u"さんま",
        u"さんみ",
        u"さんらん",
        u"しあい",
        u"しあげ",
        u"しあさって",
        u"しあわせ",
        u"しいく",
        u"しいん",
        u"しうち",
        u"しえい",
        u"しおけ",
        u"しかい",
        u"しかく",
        u"じかん",
        u"しごと",
        u"しすう",
        u"じだい",
        u"したうけ",
        u"したぎ",
        u"したて",
        u"したみ",
        u"しちょう",
        u"しちりん",
        u"しっかり",
        u"しつじ",
        u"しつもん",
        u"してい",
        u"してき",
        u"してつ",
        u"じてん",
        u"じどう",
        u"しなぎれ",
        u"しなもの",
        u"しなん",
        u"しねま",
        u"しねん",
        u"しのぐ",
        u"しのぶ",
        u"しはい",
        u"しばかり",
        u"しはつ",
        u"しはらい",
        u"しはん",
        u"しひょう",
        u"しふく",
        u"じぶん",
        u"しへい",
        u"しほう",
        u"しほん",
        u"しまう",
        u"しまる",
        u"しみん",
        u"しむける",
        u"じむしょ",
        u"しめい",
        u"しめる",
        u"しもん",
        u"しゃいん",
        u"しゃうん",
        u"しゃおん",
        u"じゃがいも",
        u"しやくしょ",
        u"しゃくほう",
        u"しゃけん",
        u"しゃこ",
        u"しゃざい",
        u"しゃしん",
        u"しゃせん",
        u"しゃそう",
        u"しゃたい",
        u"しゃちょう",
        u"しゃっきん",
        u"じゃま",
        u"しゃりん",
        u"しゃれい",
        u"じゆう",
        u"じゅうしょ",
        u"しゅくはく",
        u"じゅしん",
        u"しゅっせき",
        u"しゅみ",
        u"しゅらば",
        u"じゅんばん",
        u"しょうかい",
        u"しょくたく",
        u"しょっけん",
        u"しょどう",
        u"しょもつ",
        u"しらせる",
        u"しらべる",
        u"しんか",
        u"しんこう",
        u"じんじゃ",
        u"しんせいじ",
        u"しんちく",
        u"しんりん",
        u"すあげ",
        u"すあし",
        u"すあな",
        u"ずあん",
        u"すいえい",
        u"すいか",
        u"すいとう",
        u"ずいぶん",
        u"すいようび",
        u"すうがく",
        u"すうじつ",
        u"すうせん",
        u"すおどり",
        u"すきま",
        u"すくう",
        u"すくない",
        u"すける",
        u"すごい",
        u"すこし",
        u"ずさん",
        u"すずしい",
        u"すすむ",
        u"すすめる",
        u"すっかり",
        u"ずっしり",
        u"ずっと",
        u"すてき",
        u"すてる",
        u"すねる",
        u"すのこ",
        u"すはだ",
        u"すばらしい",
        u"ずひょう",
        u"ずぶぬれ",
        u"すぶり",
        u"すふれ",
        u"すべて",
        u"すべる",
        u"ずほう",
        u"すぼん",
        u"すまい",
        u"すめし",
        u"すもう",
        u"すやき",
        u"すらすら",
        u"するめ",
        u"すれちがう",
        u"すろっと",
        u"すわる",
        u"すんぜん",
        u"すんぽう",
        u"せあぶら",
        u"せいかつ",
        u"せいげん",
        u"せいじ",
        u"せいよう",
        u"せおう",
        u"せかいかん",
        u"せきにん",
        u"せきむ",
        u"せきゆ",
        u"せきらんうん",
        u"せけん",
        u"せこう",
        u"せすじ",
        u"せたい",
        u"せたけ",
        u"せっかく",
        u"せっきゃく",
        u"ぜっく",
        u"せっけん",
        u"せっこつ",
        u"せっさたくま",
        u"せつぞく",
        u"せつだん",
        u"せつでん",
        u"せっぱん",
        u"せつび",
        u"せつぶん",
        u"せつめい",
        u"せつりつ",
        u"せなか",
        u"せのび",
        u"せはば",
        u"せびろ",
        u"せぼね",
        u"せまい",
        u"せまる",
        u"せめる",
        u"せもたれ",
        u"せりふ",
        u"ぜんあく",
        u"せんい",
        u"せんえい",
        u"せんか",
        u"せんきょ",
        u"せんく",
        u"せんげん",
        u"ぜんご",
        u"せんさい",
        u"せんしゅ",
        u"せんすい",
        u"せんせい",
        u"せんぞ",
        u"せんたく",
        u"せんちょう",
        u"せんてい",
        u"せんとう",
        u"せんぬき",
        u"せんねん",
        u"せんぱい",
        u"ぜんぶ",
        u"ぜんぽう",
        u"せんむ",
        u"せんめんじょ",
        u"せんもん",
        u"せんやく",
        u"せんゆう",
        u"せんよう",
        u"ぜんら",
        u"ぜんりゃく",
        u"せんれい",
        u"せんろ",
        u"そあく",
        u"そいとげる",
        u"そいね",
        u"そうがんきょう",
        u"そうき",
        u"そうご",
        u"そうしん",
        u"そうだん",
        u"そうなん",
        u"そうび",
        u"そうめん",
        u"そうり",
        u"そえもの",
        u"そえん",
        u"そがい",
        u"そげき",
        u"そこう",
        u"そこそこ",
        u"そざい",
        u"そしな",
        u"そせい",
        u"そせん",
        u"そそぐ",
        u"そだてる",
        u"そつう",
        u"そつえん",
        u"そっかん",
        u"そつぎょう",
        u"そっけつ",
        u"そっこう",
        u"そっせん",
        u"そっと",
        u"そとがわ",
        u"そとづら",
        u"そなえる",
        u"そなた",
        u"そふぼ",
        u"そぼく",
        u"そぼろ",
        u"そまつ",
        u"そまる",
        u"そむく",
        u"そむりえ",
        u"そめる",
        u"そもそも",
        u"そよかぜ",
        u"そらまめ",
        u"そろう",
        u"そんかい",
        u"そんけい",
        u"そんざい",
        u"そんしつ",
        u"そんぞく",
        u"そんちょう",
        u"ぞんび",
        u"ぞんぶん",
        u"そんみん",
        u"たあい",
        u"たいいん",
        u"たいうん",
        u"たいえき",
        u"たいおう",
        u"だいがく",
        u"たいき",
        u"たいぐう",
        u"たいけん",
        u"たいこ",
        u"たいざい",
        u"だいじょうぶ",
        u"だいすき",
        u"たいせつ",
        u"たいそう",
        u"だいたい",
        u"たいちょう",
        u"たいてい",
        u"だいどころ",
        u"たいない",
        u"たいねつ",
        u"たいのう",
        u"たいはん",
        u"だいひょう",
        u"たいふう",
        u"たいへん",
        u"たいほ",
        u"たいまつばな",
        u"たいみんぐ",
        u"たいむ",
        u"たいめん",
        u"たいやき",
        u"たいよう",
        u"たいら",
        u"たいりょく",
        u"たいる",
        u"たいわん",
        u"たうえ",
        u"たえる",
        u"たおす",
        u"たおる",
        u"たおれる",
        u"たかい",
        u"たかね",
        u"たきび",
        u"たくさん",
        u"たこく",
        u"たこやき",
        u"たさい",
        u"たしざん",
        u"だじゃれ",
        u"たすける",
        u"たずさわる",
        u"たそがれ",
        u"たたかう",
        u"たたく",
        u"ただしい",
        u"たたみ",
        u"たちばな",
        u"だっかい",
        u"だっきゃく",
        u"だっこ",
        u"だっしゅつ",
        u"だったい",
        u"たてる",
        u"たとえる",
        u"たなばた",
        u"たにん",
        u"たぬき",
        u"たのしみ",
        u"たはつ",
        u"たぶん",
        u"たべる",
        u"たぼう",
        u"たまご",
        u"たまる",
        u"だむる",
        u"ためいき",
        u"ためす",
        u"ためる",
        u"たもつ",
        u"たやすい",
        u"たよる",
        u"たらす",
        u"たりきほんがん",
        u"たりょう",
        u"たりる",
        u"たると",
        u"たれる",
        u"たれんと",
        u"たろっと",
        u"たわむれる",
        u"だんあつ",
        u"たんい",
        u"たんおん",
        u"たんか",
        u"たんき",
        u"たんけん",
        u"たんご",
        u"たんさん",
        u"たんじょうび",
        u"だんせい",
        u"たんそく",
        u"たんたい",
        u"だんち",
        u"たんてい",
        u"たんとう",
        u"だんな",
        u"たんにん",
        u"だんねつ",
        u"たんのう",
        u"たんぴん",
        u"だんぼう",
        u"たんまつ",
        u"たんめい",
        u"だんれつ",
        u"だんろ",
        u"だんわ",
        u"ちあい",
        u"ちあん",
        u"ちいき",
        u"ちいさい",
        u"ちえん",
        u"ちかい",
        u"ちから",
        u"ちきゅう",
        u"ちきん",
        u"ちけいず",
        u"ちけん",
        u"ちこく",
        u"ちさい",
        u"ちしき",
        u"ちしりょう",
        u"ちせい",
        u"ちそう",
        u"ちたい",
        u"ちたん",
        u"ちちおや",
        u"ちつじょ",
        u"ちてき",
        u"ちてん",
        u"ちぬき",
        u"ちぬり",
        u"ちのう",
        u"ちひょう",
        u"ちへいせん",
        u"ちほう",
        u"ちまた",
        u"ちみつ",
        u"ちみどろ",
        u"ちめいど",
        u"ちゃんこなべ",
        u"ちゅうい",
        u"ちゆりょく",
        u"ちょうし",
        u"ちょさくけん",
        u"ちらし",
        u"ちらみ",
        u"ちりがみ",
        u"ちりょう",
        u"ちるど",
        u"ちわわ",
        u"ちんたい",
        u"ちんもく",
        u"ついか",
        u"ついたち",
        u"つうか",
        u"つうじょう",
        u"つうはん",
        u"つうわ",
        u"つかう",
        u"つかれる",
        u"つくね",
        u"つくる",
        u"つけね",
        u"つける",
        u"つごう",
        u"つたえる",
        u"つづく",
        u"つつじ",
        u"つつむ",
        u"つとめる",
        u"つながる",
        u"つなみ",
        u"つねづね",
        u"つのる",
        u"つぶす",
        u"つまらない",
        u"つまる",
        u"つみき",
        u"つめたい",
        u"つもり",
        u"つもる",
        u"つよい",
        u"つるぼ",
        u"つるみく",
        u"つわもの",
        u"つわり",
        u"てあし",
        u"てあて",
        u"てあみ",
        u"ていおん",
        u"ていか",
        u"ていき",
        u"ていけい",
        u"ていこく",
        u"ていさつ",
        u"ていし",
        u"ていせい",
        u"ていたい",
        u"ていど",
        u"ていねい",
        u"ていひょう",
        u"ていへん",
        u"ていぼう",
        u"てうち",
        u"ておくれ",
        u"てきとう",
        u"てくび",
        u"でこぼこ",
        u"てさぎょう",
        u"てさげ",
        u"てすり",
        u"てそう",
        u"てちがい",
        u"てちょう",
        u"てつがく",
        u"てつづき",
        u"でっぱ",
        u"てつぼう",
        u"てつや",
        u"でぬかえ",
        u"てぬき",
        u"てぬぐい",
        u"てのひら",
        u"てはい",
        u"てぶくろ",
        u"てふだ",
        u"てほどき",
        u"てほん",
        u"てまえ",
        u"てまきずし",
        u"てみじか",
        u"てみやげ",
        u"てらす",
        u"てれび",
        u"てわけ",
        u"てわたし",
        u"でんあつ",
        u"てんいん",
        u"てんかい",
        u"てんき",
        u"てんぐ",
        u"てんけん",
        u"てんごく",
        u"てんさい",
        u"てんし",
        u"てんすう",
        u"でんち",
        u"てんてき",
        u"てんとう",
        u"てんない",
        u"てんぷら",
        u"てんぼうだい",
        u"てんめつ",
        u"てんらんかい",
        u"でんりょく",
        u"でんわ",
        u"どあい",
        u"といれ",
        u"どうかん",
        u"とうきゅう",
        u"どうぐ",
        u"とうし",
        u"とうむぎ",
        u"とおい",
        u"とおか",
        u"とおく",
        u"とおす",
        u"とおる",
        u"とかい",
        u"とかす",
        u"ときおり",
        u"ときどき",
        u"とくい",
        u"とくしゅう",
        u"とくてん",
        u"とくに",
        u"とくべつ",
        u"とけい",
        u"とける",
        u"とこや",
        u"とさか",
        u"としょかん",
        u"とそう",
        u"とたん",
        u"とちゅう",
        u"とっきゅう",
        u"とっくん",
        u"とつぜん",
        u"とつにゅう",
        u"とどける",
        u"ととのえる",
        u"とない",
        u"となえる",
        u"となり",
        u"とのさま",
        u"とばす",
        u"どぶがわ",
        u"とほう",
        u"とまる",
        u"とめる",
        u"ともだち",
        u"ともる",
        u"どようび",
        u"とらえる",
        u"とんかつ",
        u"どんぶり",
        u"ないかく",
        u"ないこう",
        u"ないしょ",
        u"ないす",
        u"ないせん",
        u"ないそう",
        u"なおす",
        u"ながい",
        u"なくす",
        u"なげる",
        u"なこうど",
        u"なさけ",
        u"なたでここ",
        u"なっとう",
        u"なつやすみ",
        u"ななおし",
        u"なにごと",
        u"なにもの",
        u"なにわ",
        u"なのか",
        u"なふだ",
        u"なまいき",
        u"なまえ",
        u"なまみ",
        u"なみだ",
        u"なめらか",
        u"なめる",
        u"なやむ",
        u"ならう",
        u"ならび",
        u"ならぶ",
        u"なれる",
        u"なわとび",
        u"なわばり",
        u"にあう",
        u"にいがた",
        u"にうけ",
        u"におい",
        u"にかい",
        u"にがて",
        u"にきび",
        u"にくしみ",
        u"にくまん",
        u"にげる",
        u"にさんかたんそ",
        u"にしき",
        u"にせもの",
        u"にちじょう",
        u"にちようび",
        u"にっか",
        u"にっき",
        u"にっけい",
        u"にっこう",
        u"にっさん",
        u"にっしょく",
        u"にっすう",
        u"にっせき",
        u"にってい",
        u"になう",
        u"にほん",
        u"にまめ",
        u"にもつ",
        u"にやり",
        u"にゅういん",
        u"にりんしゃ",
        u"にわとり",
        u"にんい",
        u"にんか",
        u"にんき",
        u"にんげん",
        u"にんしき",
        u"にんずう",
        u"にんそう",
        u"にんたい",
        u"にんち",
        u"にんてい",
        u"にんにく",
        u"にんぷ",
        u"にんまり",
        u"にんむ",
        u"にんめい",
        u"にんよう",
        u"ぬいくぎ",
        u"ぬかす",
        u"ぬぐいとる",
        u"ぬぐう",
        u"ぬくもり",
        u"ぬすむ",
        u"ぬまえび",
        u"ぬめり",
        u"ぬらす",
        u"ぬんちゃく",
        u"ねあげ",
        u"ねいき",
        u"ねいる",
        u"ねいろ",
        u"ねぐせ",
        u"ねくたい",
        u"ねくら",
        u"ねこぜ",
        u"ねこむ",
        u"ねさげ",
        u"ねすごす",
        u"ねそべる",
        u"ねだん",
        u"ねつい",
        u"ねっしん",
        u"ねつぞう",
        u"ねったいぎょ",
        u"ねぶそく",
        u"ねふだ",
        u"ねぼう",
        u"ねほりはほり",
        u"ねまき",
        u"ねまわし",
        u"ねみみ",
        u"ねむい",
        u"ねむたい",
        u"ねもと",
        u"ねらう",
        u"ねわざ",
        u"ねんいり",
        u"ねんおし",
        u"ねんかん",
        u"ねんきん",
        u"ねんぐ",
        u"ねんざ",
        u"ねんし",
        u"ねんちゃく",
        u"ねんど",
        u"ねんぴ",
        u"ねんぶつ",
        u"ねんまつ",
        u"ねんりょう",
        u"ねんれい",
        u"のいず",
        u"のおづま",
        u"のがす",
        u"のきなみ",
        u"のこぎり",
        u"のこす",
        u"のこる",
        u"のせる",
        u"のぞく",
        u"のぞむ",
        u"のたまう",
        u"のちほど",
        u"のっく",
        u"のばす",
        u"のはら",
        u"のべる",
        u"のぼる",
        u"のみもの",
        u"のやま",
        u"のらいぬ",
        u"のらねこ",
        u"のりもの",
        u"のりゆき",
        u"のれん",
        u"のんき",
        u"ばあい",
        u"はあく",
        u"ばあさん",
        u"ばいか",
        u"ばいく",
        u"はいけん",
        u"はいご",
        u"はいしん",
        u"はいすい",
        u"はいせん",
        u"はいそう",
        u"はいち",
        u"ばいばい",
        u"はいれつ",
        u"はえる",
        u"はおる",
        u"はかい",
        u"ばかり",
        u"はかる",
        u"はくしゅ",
        u"はけん",
        u"はこぶ",
        u"はさみ",
        u"はさん",
        u"はしご",
        u"ばしょ",
        u"はしる",
        u"はせる",
        u"ぱそこん",
        u"はそん",
        u"はたん",
        u"はちみつ",
        u"はつおん",
        u"はっかく",
        u"はづき",
        u"はっきり",
        u"はっくつ",
        u"はっけん",
        u"はっこう",
        u"はっさん",
        u"はっしん",
        u"はったつ",
        u"はっちゅう",
        u"はってん",
        u"はっぴょう",
        u"はっぽう",
        u"はなす",
        u"はなび",
        u"はにかむ",
        u"はぶらし",
        u"はみがき",
        u"はむかう",
        u"はめつ",
        u"はやい",
        u"はやし",
        u"はらう",
        u"はろうぃん",
        u"はわい",
        u"はんい",
        u"はんえい",
        u"はんおん",
        u"はんかく",
        u"はんきょう",
        u"ばんぐみ",
        u"はんこ",
        u"はんしゃ",
        u"はんすう",
        u"はんだん",
        u"ぱんち",
        u"ぱんつ",
        u"はんてい",
        u"はんとし",
        u"はんのう",
        u"はんぱ",
        u"はんぶん",
        u"はんぺん",
        u"はんぼうき",
        u"はんめい",
        u"はんらん",
        u"はんろん",
        u"ひいき",
        u"ひうん",
        u"ひえる",
        u"ひかく",
        u"ひかり",
        u"ひかる",
        u"ひかん",
        u"ひくい",
        u"ひけつ",
        u"ひこうき",
        u"ひこく",
        u"ひさい",
        u"ひさしぶり",
        u"ひさん",
        u"びじゅつかん",
        u"ひしょ"
    ]
